package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````=!@``#0```"DT0````(`!30`(``)
M`"@`&P`:``$``'"\R@``O,H``+S*```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!0````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$```````````````````#(R@``R,H```4```````$`
M`0```(#-``"`S0$`@,T!`,`"``#8$@``!@```````0`"````B,T``(C-`0"(
MS0$`*`$``"@!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D@,T`
M`(#-`0"`S0$`@`(``(`"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!`````!````1TY5```````#`````@`````````$````%`````,```!'
M3E4`X/QT[1W^V++0N&93KIW^48C-&KX1````4`````@````(`````9`0!"5`
M!(`H@``!H(90@(`!```+*`2-.*`218H$"`A0````40```%4```!:````6P``
M`&(```!C````9````&8```!G`````````&D```!J````:P```&T`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M````````````M!(````````#``L```````#0`0```````P`6`+D"````````
M`````!(```!G`P`````````````2````.P,`````````````(@```(`#````
M`````````!$````E!``````````````2````$0``````````````(````"H"
M`````````````!(````-`P`````````````2````6`,`````````````$@``
M`!$!`````````````!(```"8`P`````````````1````M```````````````
M$@```-0"`````````````!(```"#`0`````````````2````P`(`````````
M````$@```(0``````````````!(````,`0`````````````2````VP(`````
M````````$@```&H"`````````````!(````Y`@`````````````2````>P(`
M````````````$@```(@"`````````````!(````!`0`````````````1````
M9P$`````````````$@```.,``````````````!$````U`0`````````````2
M````%`,`````````````$@````8#`````````````!$````=`P``````````
M```2````P@``````````````$@```+$!`````````````!(````B`@``````
M```````2````G@$`````````````$@```/0"`````````````!(````*`@``
M```````````2````J@$`````````````$@```&X#`````````````!(```!#
M`0`````````````2````+0``````````````(````)T"`````````````!(`
M``!+`@`````````````2````JP(`````````````$@```+P!````````````
M`!$```!D```````````````2````*@,`````````````$@```),`````````
M`````!(````1`@`````````````2````2@,`````````````$@```)\`````
M`````````!(```!8`@`````````````2````7`$`````````````$@```(("
M`````````````!(```"R`@`````````````2````(@$`````````````$@``
M`%8``````````````!(````6`0`````````````2````DP$`````````````
M$@```,8"`````````````!(```#P```````````````2````E@(`````````
M````$@```&`#`````````````!(```"D`@`````````````2````=0$`````
M````````$@```',``````````````!(```"!`P`````````````A````,0,`
M````````````$@```-0``````````````!(```!3`0`````````````2````
M/```````````````(````((#`````````````!$```#\`@`````````````2
M````4`(`````````````$@```)`"`````````````!(````$`@``````````
M```2````Z0(`````````````$@```&$"`````````````!(```#P`0``````
M```````2````V@,``%C@`0``````$``7`"X$``#PB0``A````!(`#0#\`P``
M$(L````````2``X`4P0``.AZ``#D"@``$@`-`'L#``#8%0``G`(``!(`#0`"
M!````',```0````2``T`RP,``$#0`0``````$``7`,$$```$<P``G`(``!(`
M#0"[!```M!(````````2``L`[@0``,R%```D!```$@`-`+\#``!`T`$`````
M`!``%P`Z!```H'4``"@````2``T`;00``!R+```$````$0`/`.T#``!8X`$`
M`````!``%P#E`P``6.`!```````0`!<`N00``%!Q``!4````$@`-`,X$``#L
M>0``_````!(`#0#@!```+'D``*0````2``T`8`0```#0`0``````$``6`$<$
M``#(=0``0`$``!(`#0"X`P``0-`!```````0`!8`H@0``#S0`0`$````$0`6
M`/(#```,BP``!````!(`#0"2!```I(H``&@````2``T`9@0``'08````````
M$@`-`&($````T`$``````"``%@`3!```T'D``!P````2``T`V0,``%C@`0``
M````$``7`'P$```8<@``Z````!(`#0"L!```"'<``"0"```2``T``&QI8G!E
M<FPN<V\N-2XR-@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N
M7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T
M97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS
M=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A
M=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D
M;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E
M90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P
M=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E
M<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R
M<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R
M87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`'!T:')E
M861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`
M;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET
M`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U
M;FQI;FL`;6MD:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T<G1O
M:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE
M;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T
M-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR
M`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO
M=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`
M;&0M;&EN=7@N<V\N,P!?7W-T86-K7V-H:U]G=6%R9`!L:6)C<GEP="YS;RXQ
M`%]E9&%T80!?7V)S<U]S=&%R=`!?7V)S<U]S=&%R=%]?`%]?8G-S7V5N9%]?
M`%]?96YD7U\`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE
M8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R
M=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C
M7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?
M9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U])
M;G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT``````````(``@`"``(``@``
M``,``@`"``(`!`````(````"```````"``(``@`"``(````````````"``(`
M`@```````P````(``P`"``(```````(``@`"```````"`````P`"`````@``
M``(``@````````````(````"``(``@```````@`"``````````(``@`"``(`
M`P`"``(``P`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0````$``0"*`P``$````"`````4:6D-
M```$``0%`````````0`!`.`!```0````(````!1I:0T```,`!`4````````!
M``$`+P(``!``````````%&EI#0```@`$!0```````(#-`0`7````A,T!`!<`
M``"\SP$`%P```.#/`0`7````Z,\!`!<```#PSP$`%P````30`0`7````#-`!
M`!<````0T`$`%P```!C0`0`7````'-`!`!<````@T`$`%P```"30`0`7````
M*-`!`!<````PT`$`%P```#30`0`7````/-`!`!<```#`SP$`%04``,3/`0`5
M"```R,\!`!4-``#,SP$`%1```-#/`0`5&0``U,\!`!4;``#8SP$`%1X``-S/
M`0`5*0``Y,\!`!4M``#LSP$`%3@``/3/`0`50@``^,\!`!5'``#\SP$`%4@`
M`+S.`0`6`P``P,X!`!8$``#$S@$`%@4``,C.`0`6!P``S,X!`!8)``#0S@$`
M%@H``-3.`0`6"P``V,X!`!8,``#<S@$`%@X``.#.`0`6#P``Y,X!`!81``#H
MS@$`%A(``.S.`0`6$P``\,X!`!84``#TS@$`%A4``/C.`0`6%@``_,X!`!87
M````SP$`%A@```3/`0`6&@``",\!`!8<```,SP$`%AT``!#/`0`6'P``%,\!
M`!8@```8SP$`%B$``!S/`0`6(@``(,\!`!8C```DSP$`%B0``"C/`0`6)0``
M+,\!`!8F```PSP$`%B<``#3/`0`6*```.,\!`!8I```\SP$`%BH``$#/`0`6
M*P``1,\!`!8L``!(SP$`%BX``$S/`0`6+P``4,\!`!8P``!4SP$`%C$``%C/
M`0`6,@``7,\!`!8S``!@SP$`%C0``&3/`0`6-0``:,\!`!8V``!LSP$`%C<`
M`'#/`0`6.0``=,\!`!8Z``!XSP$`%CL``'S/`0`6/```@,\!`!8]``"$SP$`
M%CX``(C/`0`6/P``C,\!`!9```"0SP$`%D$``)3/`0`61```F,\!`!9%``"<
MSP$`%D8``*#/`0`620``I,\!`!9*``"HSP$`%DL``*S/`0`63```L,\!`!9-
M``"TSP$`%DX``+C/`0`63P``"$`MZ8,!`.L(0+WH'O\OX03@+>4$X)_E#N"/
MX`CPON7<NP$``,:/XAO*C.+<^[SE`,:/XAO*C.+4^[SE`,:/XAO*C.+,^[SE
M`,:/XAO*C.+$^[SE`,:/XAO*C.*\^[SE`,:/XAO*C.*T^[SE`,:/XAO*C.*L
M^[SE`,:/XAO*C.*D^[SE`,:/XAO*C.*<^[SE`,:/XAO*C.*4^[SE`,:/XAO*
MC.*,^[SE`,:/XAO*C.*$^[SE`,:/XAO*C.)\^[SE`,:/XAO*C.)T^[SE`,:/
MXAO*C.)L^[SE`,:/XAO*C.)D^[SE`,:/XAO*C.)<^[SE`,:/XAO*C.)4^[SE
M`,:/XAO*C.),^[SE`,:/XAO*C.)$^[SE`,:/XAO*C.(\^[SE`,:/XAO*C.(T
M^[SE`,:/XAO*C.(L^[SE`,:/XAO*C.(D^[SE`,:/XAO*C.(<^[SE`,:/XAO*
MC.(4^[SE`,:/XAO*C.(,^[SE`,:/XAO*C.($^[SE`,:/XAO*C.+\^KSE`,:/
MXAO*C.+T^KSE`,:/XAO*C.+L^KSE`,:/XAO*C.+D^KSE`,:/XAO*C.+<^KSE
M`,:/XAO*C.+4^KSE`,:/XAO*C.+,^KSE`,:/XAO*C.+$^KSE`,:/XAO*C.*\
M^KSE`,:/XAO*C.*T^KSE`,:/XAO*C.*L^KSE`,:/XAO*C.*D^KSE`,:/XAO*
MC.*<^KSE`,:/XAO*C.*4^KSE`,:/XAO*C.*,^KSE`,:/XAO*C.*$^KSE`,:/
MXAO*C.)\^KSE`,:/XAO*C.)T^KSE`,:/XAO*C.)L^KSE`,:/XAO*C.)D^KSE
M`,:/XAO*C.)<^KSE`,:/XAO*C.)4^KSE`,:/XAO*C.),^KSE`,:/XAO*C.)$
M^KSE`,:/XAO*C.(\^KSE`,:/XAO*C.(T^KSE`,:/XAO*C.(L^KSE`,:/XAO*
MC.(D^KSE`,:/XAO*C.(<^KSE`,:/XAO*C.(4^KSE`,:/XAO*C.(,^KSE`,:/
MXAO*C.($^KSE`,:/XAO*C.+\^;SE`,:/XAO*C.+T^;SE`,:/XAO*C.+L^;SE
M`,:/XAO*C.+D^;SE\$`MZ412G^4DT$WB%`"-Y1`0C>4,((WE-#*?Y050C^`#
M0)7G`#"4Y0P@C>(0$(WB%`"-XAPPC>69___K%"*?Y10RG^4"()7G`P"5YP(0
MH.$1'0#K!#*?Y0,PE><`<-/E``!7XU,```KT,9_E`V"5YP``EN7>___K`""@
MX0XTT.4",(/C#C3"Y0``EN78___K%#"=Y0XDT.4%,(/B`2""XP<!<^,.),#E
M6```B@,!H.%=___K`,"@X00`H.,0,)WEH"&?Y0`0D^4"((_@`!",Y901G^4`
MX)+E`1"/X`)`C.F($9_E`1"/X!0@G>4,$(SE?!&?Y0$`4N,!$(_@`1"!Z08`
M`-H$X$/B`N&.X`P0C.($`+/E#@!3X00`H>7[__\:`!"@XTQ1G^4-X8+B!5"/
MX!``E>4.$8SG`!"-Y3@1G^4#((+B##"@X0$0C^!X___K`&!0XBD```H@49_E
M!5"/X!``E>4;___K%`&?Y1APC>('$*#A``"/X-(4`.L``%#C&0``"OPPG^4#
M,(_@$`"3Y?[^_^M@___K'""=Y0`PE.4#`%+A!@"@X24``!HDT(WB\$"]Z![_
M+^$5___KR#"?Y0``4.,#,(_@$`"#Y1T```KK_O_KB#"?Y0-@E><``);E@___
MZX%VP.6@___J#`"5Y0``4.,*```*AAP`Z^#__^H0`)7E9?__ZP!@H.'1___J
M>#"?Y7@`G^4#$)7G``"/X"[__^ML`)_E!Q"@X0``C^"D%`#K``!0XPP`A>70
M__\*[/__ZM?^_^L!`*#C#O__Z[2X`0`8`0``/`$``$0!```D`0``(`$``)2Y
M`0"@=P``F'<``&RY`0`XN0$`?%H```BY`0#`=```W+@!`*"X`0`T`0``F'4`
M`*1S````L*#C`."@XP00G>0-(*#A!"`MY00`+>4HH)_E)#"/X@.@BN`@P)_E
M#,":YP3`+>48,)_E`S":YQ0`G^4``)KGWO[_ZS?__^OTM0$`#`$``#@!``!`
M`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!V/[_ZM2U`0`L`0``+`"?Y2PP
MG^4``(_@`S"/X```4^$@,)_E`S"/X![_+P$8()_E`C"3YP``4^,>_R\!$_\O
MX4"W`0`\MP$`H+4!`!0!```X`)_E.#"?Y0``C^`#,(_@`!!#X$$1H.&A'X'@
M)#"?Y<$0L.$#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_A_+8!`/BV`0!0
MM0$`2`$``$PPG^4#,(_@`##3Y0``4^-`,)_E`S"/X![_+Q$00"WI-""?Y0(P
MD^<``%/C+#"?%0,`GQ=,_O\;R___ZP$@H.,<,)_E`S"/X``@P^400+WH'O\O
MX;"V`0`0M0$`$`$``$BV`0!PM@$`T/__ZO!/+>F]WTWB:#"-X@/`H.$`X*#C
M`X"@X5`EG^4(`(WE3!6?Y0(@C^`!()+G9""-Y0`@DN6`D(#B["*-Y4`@@.(`
M4*#C#A"%X0!0H.,$,!+E(P2@X2-LH.'_3`#B!@"$X0.DH.$#;*#A!@"`X?](
M"N($`(#A"$`2Y60X).`C-*#A""""XO\\P^,%$('A9#0CX`(`6>$$X(SE"`",
MY0P0C.4`,(SE$,",XN3__QH(,*#A`BR(XF@0@^(#`)'H0%"#XC``E>@$8"#@
M!7`AX!!0@^(P`)7H!``FX`40)^`P`)/H!(`@X`60(>"H;Z#A"$"8X(E@AN$&
M@(3A"`"@X0`0H.,(,(/B`@!3X7@`@^5\$(/EY___&@!@H.,`<*#C"."=Y0B0
MCN(``YGH&+".X@`,F^@0@(WE%)"-Y1"0CN(``YGH(*"-Y22PC>4(H*#A!@"@
MX0<0H.$8@(WE')"-Y2"0C>(``YGH"*`JX!"0C>(``YGH"7^@X2AQA^$(;Z#A
M*5&@X0>`AN$%D(?A"&"@X0EPH.$P`)[H\\^/X@`8G.B%,J#AI,V@X0,`C>@@
MD([B``.9Z`#`C>6D/8/AI<V@X0`PC>4$P(WE2("-Y4R0C>4``YWH:!"-X@,`
MD>B$(J#A`H"(X4@PC>(,`)/H`+";X`L@DN`"`*#A$#"-X@P`D^@*(`+@`J"@
MX2A@C>4L<(WE`'"@XP@@D.`@$(WB`P"1Z`H`(.``H*#A&!"-X@,`D>@'@*#A
M,&"-Y31PC>4&`"#@!6"@X0@0(>`!8`;@!A"@X0!PH.,`8*#C.$"-Y3Q0C>4$
M4*#A"B"2X+^?C^(``YGH<+"-X@`,F^@*@)C@"*"@X0<PH.$"@*#A!B"@X0!0
M!>`%`*#A`)"@XPP`C>@@,(WB#`"3Z`H@DN`"H*#A&#"-X@P`D^@`("+@`3`C
MX$`@C>5$,(WE.#"-X@P`D^@#?Z#A(G&'X0)OH.$C4:#A!P"&X040A^$`8*#A
M`7"@X0B`C>4,D(WE"$"-XA@`E.B$(J#A!""-Y00@G>6C+8+A!""-Y8,BH.$`
M((WEHXV@X0,`G>B$@HCA0$"-XA@`E.@(`(#A*%"-XC``E>@*,)/@`*"3X`@P
MC>(,`)/H!D`DX`=0)>`$(`+@!3`#X$!@C>5$<(WE`X"@X0)PH.%X$(WB`P"1
MZ'U/C^(8`)3H`#"3X%!PC>54@(WE`P"@X0H@H.$`8*#C`'"@XP`PH.,&@*#A
M*""-Y2PPC>4'D*#A4#"-X@P`D^@PL(WB``R;Z`*@*N`*(*#A&+"-X@`,F^A`
MP(WB`!B<Z`LPH.$,0*#A`*":X`@0C>(#`)'H`7^@X2!QA^$`;Z#A(5&@X040
MA^$'`(;A*'"-XL``E^@(`(WE#!"-Y8<2H.$``XWH!!"-Y000G>4*4)+@IAV!
MX000C>4%D*#AAA*@X::-H.$(8(WB8`"6Z`4P(^`&0"3@!%"@X0-`H.$`$(WE
M`P"=Z(>"B.$H,(WB#`"3Z`@`@.$`8)G@!"`"X`4P`^!0((WE5#"-Y08@H.$`
M,*#C@)"-X@`#F>C<4(_B,`"5Z#!PC>+``)?H"$"4X`E0I>`$8);@!7"GX`P`
MC>A`8(WE1'"-Y2APC>+``)?H!U^@X291A>$&3Z#A)Q&@X05@A.$!<(7A*&"-
MY2QPC>4(<(WBP`"7Z`9`H.$'4*#A`'"@XP,`G>A0,(WB#`"3Z(&2H.&@G8GA
M@(*@X4`0C>(#`)'H"R`BX`(`D.`(((GA*)"-X@`#F>@`P*#C"$`DX`*`D.!`
M8(WE1'"-Y0A@H.$`<*#C`P"=Z`E0)>"(,(WB#`"3Z`0``.`%$`'@#%"/XC``
ME>A0`(WE5!"-Y0,``.J9>8):`````)2T`0`8`0```D"4X`-0I>!`D(WB``.9
MZ%`PC>(,`)/H,+"-Y33`C>4(8(WE#'"-Y0@@(N`P<(WBP`"7Z`DP(^!0((WE
M5#"-Y0P`G>@$8);@!7"GX`-?H.$B487A`D^@X2,1H.$%((3A`3"%X3`@C>4T
M,(WE"#"-X@P`D^B#LJ#A4$"-XA@`E.@#8);@!'"GX"A0C>(P`)7H!`"@X040
MH.'``(WHHKV+X3!PC>+``)?H@J*@X0HPB^$(L(WB``R;Z`8`(.`'$"'@`*`*
MX`&P"^`+P*#A"K"@X<``G>@`4*#C`V"6X"BPC>4LP(WE!J"@X0"PH..0,(WB
M#`"3Z/$?C^(#`)'H4$"-Y510C>4"`)#@`Q"AX``,C>A`D(WB``.9Z"@PC>(,
M`)/H4'"-XL``E^@&("+@!S`CX$`@C>5$,(WE"#"-X@P`D^@`@)C@`U^@X0&0
MJ>`B487A`D^@X2,1H.$%((3A`3"%X2@@C>4L,(WE#`"=Z(.RH.%`0(WB&`"4
MZ`.`F.`$D*G@,%"-XC``E>@$`*#A!1"@X0B`C>4,D(WEHKV+X2B0C>(``YGH
M@J*@X0HPB^$`#)WH"``@X`D0(>``H`K@`;`+X`O`H.$*L*#A`%"@XPB0C>(`
M`YGH`X"8X#"PC>4TP(WE"*"@X0"PH..8,(WB#`"3Z+(?C^(#`)'H0$"-Y410
MC>4"`)#@`Q"AX$"0C>(``YGH,#"-X@P`D^@(("+@"3`CX%!PC>+``)?H4""-
MY50PC>4,`)WH`&"6X`-?H.$!<*?@(E&%X0)/H.$C$:#A"*"-Y0RPC>4%((3A
M`3"%X3`@C>4T,(WE"#"-X@P`D^B#LJ#A4$"-XA@`E.@#8);@!'"GX"A0C>(P
M`)7H!`"@X040H.'``(WHHKV+X3!PC>+``)?H@J*@X0HPB^$(L(WB``R;Z`8`
M(.`'$"'@`*`*X`&P"^`+P*#A"K"@X<``G>@#8);@*+"-Y2S`C>4&H*#A`%"@
MXP"PH..@,(WB#`"3Z',?C^(#`)'H`@"0X`,0H>!00(WE5%"-Y0`,C>A`D(WB
M``.9Z"@PC>(,`)/H4'"-XL``E^@&("+@!S`CX$`@C>5$,(WE"#"-X@P`D^@`
M@)C@`U^@X0&0J>`B487A`D^@X2,1H.$%((3A`3"%X2@@C>4L,(WE#`"=Z(.R
MH.%`0(WB&`"4Z`.`F.`$D*G@,%"-XC``E>@$`*#A!1"@X0B`C>4,D(WEHKV+
MX2B0C>(``YGH@J*@X0HPB^$`#)WH"``@X`D0(>``H`K@`;`+X`O`H.$*L*#A
M`%"@XPB0C>(``YGH`X"8X#"PC>4TP(WE"*"@X0"PH..H,(WB#`"3Z-`0C^(#
M`)'H0$"-Y410C>4"`)#@`Q"AX$"0C>(``YGH,#"-X@P`D^@(("+@"3`CX%!P
MC>+``)?H4""-Y50PC>4,`)WH`&"6X`-?H.$!<*?@(E&%X0)/H.$C$:#A"*"-
MY0RPC>4%((3A`3"%X3`@C>4T,(WE"#"-X@P`D^B#LJ#A4$"-XA@`E.@#8);@
M!'"GX"A0C>(P`)7H!`"@X040H.&BO8OA@J*@X<``C>@P<(WBP`"7Z`HPB^$(
ML(WB``R;Z`8`(.`'$"'@`*`*X`&P"^`+P*#A`P``ZIEY@EH`````F7F"6@``
M```*L*#A`%"@X\``G>@#8);@*+"-Y2S`C>4&H*#A`+"@X[`PC>(,`)/H.!!/
MX@,`D>@"`)#@4$"-Y510C>4#$*'@4'"-XL``E^@H,(WB#`"3Z`8@(N`',"/@
M0)"-X@`#F>A`((WE1#"-Y0@PC>(,`)/H`("8X`-?H.$!D*G@(E&%X0)/H.$C
M$:#A``R-Z`4@A.$!,(7A*""-Y2PPC>4,`)WH@[*@X4!`C>(8`)3H`X"8X`20
MJ>`P4(WB,`"5Z`0`H.$%$*#A"("-Y0R0C>6BO8OA*)"-X@`#F>B"HJ#A"C"+
MX0`,G>@(`"#@"1`AX`"@"N`!L`O@"\"@X0JPH.$`4*#C")"-X@`#F>@#@)C@
M,+"-Y33`C>4(H*#A`+"@X[@PC>(,`)/H31]/X@,`D>A`0(WE1%"-Y0(`D.`#
M$*'@0)"-X@`#F>@P,(WB#`"3Z`@@(N`),"/@4'"-XL``E^A0((WE5#"-Y0P`
MG>@`8);@`U^@X0%PI^`B487A`D^@X2,1H.$(H(WE#+"-Y04@A.$!,(7A,""-
MY30PC>4(,(WB#`"3Z(.RH.%00(WB&`"4Z`-@EN`$<*?@*%"-XC``E>@$`*#A
M!1"@X:*]B^&"HJ#AP`"-Z#!PC>+``)?H"C"+X0BPC>(`#)OH!@`@X`<0(>``
MH`K@`;`+X`O`H.$*L*#A`%"@X\``G>@#8);@!J"@X<`PC>(,`)/H*+"-Y2S`
MC>4`L*#C(QY/X@,`D>A00(WE5%"-Y0(`D.!0<(WBP`"7Z`,0H>`H,(WB#`"3
MZ`8@(N`',"/@0)"-X@`#F>A`((WE1#"-Y0@PC>(,`)/H`("8X`-?H.$!D*G@
M(E&%X0)/H.$C$:#A``R-Z`4@A.$!,(7A*""-Y2PPC>4,`)WH@[*@X4!`C>(8
M`)3H`X"8X`20J>`P4(WB,`"5Z`0`H.$%$*#A"("-Y0R0C>6BO8OA*)"-X@`#
MF>B"HJ#A"C"+X0`,G>@(`"#@"1`AX`"@"N`!L`O@"\"@X0JPH.$`4*#C")"-
MX@`#F>@#@)C@,+"-Y33`C>4(H*#A`+"@X\@PC>(,`)/HRQ]/X@,`D>A`0(WE
M1%"-Y0(`D.`#$*'@0)"-X@`#F>@P,(WB#`"3Z`@@(N`),"/@4'"-XL``E^A0
M((WE5#"-Y0P`G>@`8);@`U^@X0%PI^`B487A`D^@X2,1H.$(H(WE#+"-Y04@
MA.$!,(7A,""-Y30PC>4(,(WB#`"3Z(.RH.%00(WB&`"4Z`-@EN`$<*?@*%"-
MXC``E>@$`*#A!1"@X<``C>@P<(WBP`"7Z**]B^&"HJ#A!@`@X`<0(>#``)WH
M"C"+X0-@EN#0,(WB#`"3Z`BPC>(`#)OH`*`*X`&P"^`+P*#A"K"@X0!0H.,H
ML(WE+,"-Y0:@H.$`L*#C#QV/X@,`D>A00(WE5%"-Y0(`D.!0<(WBP`"7Z`,0
MH>`H,(WB#`"3Z`8@(N`',"/@0)"-X@`#F>A`((WE1#"-Y0@PC>(,`)/H`("8
MX`-?H.$!D*G@(E&%X0)/H.$C$:#A``R-Z`4@A.$!,(7A*""-Y2PPC>4,`)WH
M@[*@X4!`C>(8`)3H`X"8X`20J>`P4(WB,`"5Z`0`H.$%$*#A"("-Y0R0C>6B
MO8OA*)"-X@`#F>B"HJ#A"C"+X0`,G>@(`"#@"1`AX`"@"N`!L`O@"\"@X0JP
MH.$`4*#C")"-X@`#F>@#@)C@,+"-Y33`C>4(H*#A`+"@X]@PC>(,`)/HL1^/
MX@,`D>A`0(WE1%"-Y0(`D.`#$*'@0)"-X@`#F>@P,(WB#`"3Z`@@(N`),"/@
M4'"-XL``E^A0((WE5#"-Y0P`G>@`8);@`U^@X0%PI^`B487A`D^@X2,1H.$(
MH(WE#+"-Y04@A.$!,(7A,""-Y30PC>4(,(WB#`"3Z(.RH.%00(WB&`"4Z`-@
MEN`$<*?@*%"-XC``E>@$`*#A!1"@X<``C>@P<(WBP`"7Z**]B^&"HJ#A"C"+
MX08`(.`'$"'@P`"=Z`BPC>(`#)OH`*`*X`&P"^`+P*#A"K"@X0!0H.,#8);@
M*+"-Y2S`C>4&H*#A`+"@X^`PC>(,`)/H<A^/X@,`D>A00(WE5%"-Y0(`D.`#
M$*'@4'"-XL``E^@H,(WB#`"3Z`8@(N`',"/@0)"-X@`#F>A`((WE1#"-Y0@P
MC>(,`)/H`("8X`-?H.$!D*G@(E&%X0)/H.$C$:#A``R-Z`4@A.$!,(7A*""-
MY2PPC>48`)WHA+*@X:.]B^&#HJ#A0$"-XA@`E.@#@)C@!)"IX#!0C>(P`)7H
M!1"@X0!0H.,$`*#A,$"-Y310C>4`4*#C"("-Y0R0C>4HD(WB``.9Z`H@B^$(
M`"#@``R=Z`D0(>`(D(WB``.9Z`"@"N`"@)C@`;`+X.@PC>(,`)/HV!"/X@,`
MD>@+P*#A`@"0X`JPH.$`(*#A!1"@X0!`H.-0<(WBP`"7Z$"PC>5$P(WE"*"@
MX0"PH.,PD(WB``.9Z`)@EN!`,(WB#`"3Z`@@(N`),"/@0""-Y40PC>4$(*#A
M`3"@X0`#G>@)7Z#A"*"-Y0RPC>4H487A*1&@X0&0A>$($(WB`P"1Z`P`C>B!
MLJ#AH#V@X0`PC>6@O8OAH3V@X0A/H.$%@(3A`+"-Y00PC>5`0(WB&`"4Z"A0
MC>(P`)7H@**@X00`H.$`4*#C`V"6X`P`G>A0@(WE5)"-Y04``.J9>8):````
M`)EY@EH`````H>O9;@`````(`"#@")"-X@`#F>@*((+A`F"6X`"`".!`0(WE
M1%"-Y0BPH.$`0*#C!H"@X0!0H.,`D*#C\#"-X@P`D^A4$$_B`P"1Z`(`D.``
M(*#A*("-Y2R0C>4P<(WBP`"7Z`6`H.$$<*#A`)"@XP"@H.,"8);@!B"@X8`!
MC>A`<(WBP`"7Z`:P*^`(<(WBP`"7Z`=?H.$F487A)Q&@X0%PA>$H$(WB`P"1
MZ`9/H.$%8(3A@4*@X01`C>6@3:#A")"-Y0R@C>4(0(WE!$"=Y:!-A.$$0(WE
M"$"=Y8%"A.$(0(WEH1V@X8!"H.$,$(WE`$"-Y0LPDN!0$(WB`P"1Z#``G>@#
ML*#A"#"-X@P`D^@!4*#A!"""X0!`H.$"@)O@`!"@X\``C>@&0"3@!U`EX`A@
MH.$`<*#C*+"-X@`,F^CX,(WB#`"3Z`2@"N`%L`O@%EY/XC``E>A`D(WB``.9
MZ`)`E.`#4*7@!("8X`60J>`(`(WE#!"-Y3!@C>4T<(WE0("-Y420C>4(,(WB
M#`"3Z`H@(N`+,"/@*+"-X@`,F^@+7Z#A*E&%X2L1H.$!P(7A"D^@X3`0C>(#
M`)'H!;"$X2BPC>4LP(WE@<*@X:#-C.$,D*#A`F"@X0-PH.&`PJ#A0!"-X@,`
MD>@)0(SA`&"6X`0@H.$P`)WH`7"GX`:@H.$'L*#A!&"@X05PH.$H$(WB`P"1
MZ`!@)N`!<"?@!H"@X0>0H.$"8)K@`'"KX@?`H.$&L*#A"7"@X0A@H.$P,(WB
M#`"3Z`$<C>(#`)'H`F`&X`-P!^"9/T_B#`"3Z``@DN`!,*/@`@"@X0,0H.$`
M4*#C")"-X@`#F>@`@)C@!`"@X0&0J>`%$*#A0+"-Y43`C>4`P*#C"R"@X0"@
MH.,`L*#C!@`@X`!@H.$'$"'@`7"@X0PPH.%80(WE7%"-Y0I`H.$+4*#A!H"8
MX`>0J>`(8*#A"7"@X8RRH.$PD(WB``.9Z**]B^&CS:#A`+"-Y03`C>4)'Z#A
M*,&@X0A`C>4,4(WE*!&!X3``G>@(P(WE*<&@X0@0C>4,P(WE@J*@X0I`A.$(
MH(WB``::Z`@/H.$HP(WB`!B<Z`"0B>$!H(KA!`"6X``0I^((D(WE#*"-Y4)_
MC>+``)?H";`KX#:>3^(``YGH!H"8X`>0J>`)<*#A`)"@XPK`+.`+0*#A#%"@
MX5``C>54$(WE"1"@X0A@H.%`P(WB`!B<Z`2P*^`%P"S@,+"-Y33`C>584(WB
M,`"5Z*'-H.$$P(WE,,"=Y09`E.")DJ#A!U"EX*"=B>$,0)3@`%"EX@"0C>4#
MOZ#A,$"-Y310C>4P`)WH(K&+X8""H.$"KZ#A(W&@X0>0B^$(0(3A"X"*X0BP
MH.$)P*#A,)"-X@`#F>@$@)C@"%"-XC``E>@1?HWBP`"7Z#"PC>4TP(WE"T`D
MX#Z^C^(`#)OH`)"IX@:@FN`*8*#A`*"@XP>PJ^`,4"7@"W"@X5#`C>(`&)SH
M!+`KX`7`+.!0L(WE5,"-Y2C`G>4,0);@BL*@X:C-C.$,8*#A!,"-Y8C"H.$`
MP(WE4,"=Y0!0I^(,0)3@`%"EXD"`C>5$D(WE*$"-Y2Q0C>4!GZ#A,`"=Z`@@
MH.$@D8GA`(^@X2&QH.$&0(3A"W")X0E@B.$*,*#A!["@X0:@H.$H$(WB`P"1
MZ`0`D.`P4(WB,`"5Z$9_C>+``)?H**"-Y2RPC>4*0"3@PZ^/X@`&FN@+P*#A
M`!"AX@:0F>`)8*#A4`"-Y500C>4`$*#C0)"-X@`#F>@,4"7@","=Y0>@JN`$
M@"C@#$"6X('"H.&@S8SA#&"@X060*>!`@(WE1)"-Y03`C>6`PJ#A`,"-Y4#`
MG>4`4*KB#$"4X`!0I>(#GZ#A"$"-Y0Q0C>4BD8GA,`"=Z".QH.$+<(GA","-
MX@`8G.@&0(3A`H^@X02PF^`)8(CA!I"@X0>@H.$`P*SB0+"-Y43`C>4`P*#C
M*$"-XA@`E.@),"/@"D`DX`10H.$#0*#A##"@X1)^C>+``)?H")"-Y0R@C>4B
MGH_B``.9Z`:`F.`'D*G@"7"@X5"@C>(`!IKH,,"=Y020*>`,0)C@@\*@X:O-
MC.$,8*#A!:`JX%"0C>54H(WE!,"-Y8O"H.$`P(WE4,"=Y0!0I^(,0)3@`%"E
MXC!`C>4T4(WE`9^@X3``G>@+(*#A()&)X0"/H.$AL:#A!D"$X0MPB>$)8(CA
M!H"@X0>0H.$P$(WB`P"1Z`0`D.``$*'B4`"-Y500C>4`$*#C"%"-XC``E>A`
MP(WB`!B<Z`A`).`)4"7@2G^-XL``E^@P@(WE-)"-Y02P*^`%P"S@4:^/X@`&
MFNA`L(WE1,"-Y2C`G>4&D)G@!Z"JX`Q`F>"!PJ#AH,V,X0Q@H.$$P(WE@,*@
MX0#`C>5`P)WE`%"JX@Q`E.``4*7B`Y^@X2A`C>4L4(WE(I&)X3``G>@CL:#A
M"W")X2C`C>(`&)SH!D"$X0*/H.$$L)O@"6"(X0:0H.$'H*#A`,"LXD"PC>5$
MP(WE`,"@XS!`C>(8`)3H"3`CX`I`).`$4*#A`T"@X0PPH.$3?HWBP`"7Z"B0
MC>4LH(WEA)"/X@`#F>@&@)C@!Y"IX`EPH.$(P)WE4*"-X@`&FN@$D"G@#$"8
MX(/"H.&KS8SA#&"@X06@*N!0D(WE5*"-Y03`C>6+PJ#A`,"-Y5#`G>4`4*?B
M#$"4X`!0I>((0(WE#%"-Y0&?H.$P`)WH()&)X0"/H.$&0(3A"6"(X0:@H.$+
M(*#A!```Z@``H.&AZ]EN`````*'KV6X`````(;&@X0MPB>$'L*#A"!"-X@,`
MD>@*D*#A!`"0X``0H>)0`(WE5!"-Y0`0H.,H4(WB,`"5Z`B@C>4,L(WE"U`E
MX$#`C>(`&)SH"4`DX$Y_C>+``)?H!+`KX`7`+.!LH$_B``::Z$"PC>5$P(WE
M,,"=Y0:0F>`'H*K@#$"9X('"H.&@S8SA#&"@X03`C>6`PJ#A`,"-Y4#`G>4`
M4*KB#$"4X`!0I>(P0(WE-%"-Y0.?H.$P`)WH(I&)X0*/H.$CL:#A!D"$X0MP
MB>$)8(CA,,"-X@`8G.@&@*#A!Y"@X02PF^``P*SB0+"-Y43`C>4`P*#C"$"-
MXA@`E.@%?8WBP`"7Z#"`C>4TD(WE"4`DX$>O3^(`!IKH"#`CX`:0F>`$4*#A
M"6"@X0-`H.$,,*#A!Z"JX"C`G>4*<*#A4*"-X@`&FN@$D"G@#$"6X(/"H.&K
MS8SA#&"@X06@*N!0D(WE5*"-Y03`C>6+PJ#A`,"-Y5#`G>4`4*?B#$"4X`!0
MI>(H0(WE+%"-Y0&?H.$P`)WH"R"@X2"1B>$`CZ#A(;&@X0MPB>$&0(3A"6"(
MX0:0H.$'H*#A*!"-X@,`D>@$`)#@`!"AXE``C>54$(WE`!"@XS!0C>(P`)7H
M4G^-XL``E^@HD(WE+*"-Y4#`C>(`&)SH"4`DX`I0)>`$L"O@!<`LX(.O3^(`
M!IKH0+"-Y43`C>4(P)WE!I"9X`>@JN`,0)G@@<*@X:#-C.$,8*#A!,"-Y8#"
MH.$`P(WE0,"=Y0!0JN(,0)3@`%"EX@A`C>4,4(WE`Y^@X3``G>@BD8GA`H^@
MX2.QH.$&0(3A"W")X0E@B.$(P(WB`!B<Z`:`H.$'D*#A!+";X`#`K.)`L(WE
M1,"-Y0#`H.,H0(WB&`"4Z!5^C>+``)?H"("-Y0R0C>4)0"3@KZ]/X@`&FN@(
M,"/@!I"9X`10H.$)8*#A`T"@X0PPH.$'H*K@,,"=Y0IPH.%0H(WB``::Z`20
M*>`,0);@@\*@X:O-C.$,8*#A!:`JX%"0C>54H(WE!,"-Y8O"H.$`P(WE4,"=
MY0!0I^(,0)3@`%"EXC!`C>4T4(WE`9^@X3``G>@+(*#A()&)X0"/H.$AL:#A
M"W")X09`A.$)8(CA!I"@X0>@H.$P$(WB`P"1Z`0`D.``$*'B4`"-Y500C>4`
M$*#C"%"-XC``E>A6?XWBP`"7Z#"0C>4TH(WE"E`EX.:_3^(`#)OH!J":X`>P
MJ^`+<*#A0,"-X@`8G.@)0"3@!+`KX`7`+.!`L(WE1,"-Y2C`G>4,0)K@@<*@
MX:#-C.$,8*#A!,"-Y8#"H.$`P(WE0,"=Y0!0I^(,0)3@`%"EXBA`C>4L4(WE
M`Y^@X3``G>@BD8GA`H^@X2.QH.$&0(3A"W")X0E@B.$HP(WB`!B<Z`:`H.$'
MD*#A!+";X`#`K.)`L(WE1,"-Y0#`H.,P0(WB&`"4Z!9^C>+``)?H*("-Y2R0
MC>4)0"3@/JZ/X@`&FN@(,"/@!I"9X`10H.$)8*#A`T"@X0PPH.$'H*K@","=
MY0IPH.%0H(WB``::Z`20*>`,0);@@\*@X:O-C.$,8*#A!:`JX%"0C>54H(WE
M!,"-Y8O"H.$`P(WE4,"=Y0!0I^(,0)3@`%"EX@A`C>4,4(WE`9^@X3``G>@+
M(*#A()&)X0"/H.$AL:#A"W")X09`A.$)8(CA!I"@X0>@H.$($(WB`P"1Z`0`
MD.``$*'B4`"-Y500C>4`$*#C*%"-XC``E>A:?XWBP`"7Z`B0C>4,H(WE"E`E
MX,&_C^(`#)OH!J":X`>PJ^`+<*#A0,"-X@`8G.@)0"3@!+`KX`7`+.!`L(WE
M1,"-Y3#`G>4,0)K@@<*@X:#-C.$,8*#A!,"-Y8#"H.$`P(WE0,"=Y0!0I^(,
M0)3@`%"EXC!`C>4T4(WE`Y^@X3``G>@BD8GA`H^@X2.QH.$&0(3A"W")X0E@
MB.$PP(WB`!B<Z`:`H.$'D*#A!+";X`#`K.)`L(WE1,"-Y0#`H.,(0(WB&`"4
MZ!=^C>+``)?H,("-Y320C>4)0"3@CZ^/X@`&FN@(,"/@!I"9X`10H.$)8*#A
M`T"@X0PPH.$'H*K@"G"@X5"@C>(`!IKH*,"=Y020*>`,0);@@\*@X:O-C.$,
M8*#A!:`JX%"0C>54H(WE!,"-Y8O"H.$`P(WE4,"=Y0!0I^(,0)3@`%"EXBA`
MC>4L4(WE`9^@X3``G>@+(*#A()&)X0"/H.$AL:#A"W")X09`A.$)8(CA!I"@
MX0>@H.$H$(WB`P"1Z`0`D.``$*'B4`"-Y500C>4`$*#C,%"-XC``E>A>?XWB
MP`"7Z"B0C>4LH(WE"E`EX!:^C^(`#)OH!J":X`>PJ^`+<*#A0,"-X@`8G.@)
M0"3@!+`KX`7`+.!`L(WE1,"-Y0C`G>4,0)K@@<*@X:#-C.$,8*#A!,"-Y8#"
MH.$`P(WE0,"=Y0!0I^(,0)3@`%"EX@A`C>4,4(WE`Y^@X3``G>@BD8GA`H^@
MX2.QH.$&0(3A"W")X0E@B.$(P(WB`!B<Z`:`H.$'D*#A!+";X`#`K.)`L(WE
M1,"-Y0#`H.,H0(WB&`"4Z`9]C>+``)?H"("-Y0R0C>4)0"3@F*"/X@`&FN@(
M,"/@!I"9X`10H.$)8*#A`T"@X0PPH.$'H*K@"G"@X3#`G>50H(WB``::Z`20
M*>`,0);@@\*@X:O-C.$,8*#A!:`JX%"0C>54H(WE!,"-Y8O"H.$`P(WE4,"=
MY0!0I^(,0)3@`%"EXC!`C>4T4(WE`9^@X3``G>@+(*#A()&)X0"/H.$AL:#A
M"W")X09`A.$&``#J``"@X:'KV6X`````H>O9;@````#<O!N/``````E@B.$&
MD*#A!Z"@X3`0C>(#`)'H!`"0X``0H>)0`(WE5!"-Y0`0H.,(4(WB,`"5Z&)_
MC>+``)?H,)"-Y32@C>4*4"7@7+!/X@`,F^@&H)K@!["KX`MPH.%`P(WB`!B<
MZ`E`).`$L"O@!<`LX$"PC>5$P(WE*,"=Y0Q`FN"!PJ#AH,V,X0Q@H.$$P(WE
M@,*@X0#`C>5`P)WE`%"GX@Q`E.``4*7B*$"-Y2Q0C>4#GZ#A,`"=Z"*1B>$"
MCZ#A([&@X09`A.$+<(GA"6"(X2C`C>(`&)SH!H"@X0>0H.$$L)O@`,"LXEBP
MC>5<P(WE`,"@XS!`C>(8`)3H&7Z-XL``E^@H@(WE+)"-Y0E`).!)KT_B``::
MZ`@P(^`&D)G@!%"@X0E@H.$#0*#A##"@X0>@JN`(P)WE"G"@X5"@C>(`!IKH
M!)`IX`Q`EN"#PJ#AJ\V,X0Q@H.$%H"K@0)"-Y42@C>4$P(WEB\*@X0#`C>5`
MP)WE`%"GX@Q`E.``4*7B"$"-Y0Q0C>4!GZ#A,`"=Z`L@H.$@D8GA`(^@X2&Q
MH.$+<(GA!D"$X0E@B.$&D*#A!Z"@X0@0C>(#`)'H!`"0X"A0C>(P`)7H9G^-
MXL``E^A`D(WE1*"-Y0I0)>`?OD_B``R;Z``0H>(&H)K@!["KX`MPH.%0`(WE
M5!"-Y0`0H.-8P(WB`!B<Z`E`).`%P"S@,%"=Y02P*^`(L(WE#,"-Y06PFN``
MP*?B#%"@X8'"H.&@S8SA!,"-Y0Q@H.&`PJ#A`,"-Y0C`G>4#GZ#A#$";X"*1
MB>$CL:#A"W")X0<PH.$`4*7B"$"-Y0Q0C>4P`)WH`H^@X09`A.$)8(CA!B"@
MX0APC>+``)?H!&"6X`-`H.$&H*#A0&"-XF``EN@:GHWB``.9Z#`@C>4T,(WE
M!&`FX+%/3^(8`)3H"#"3X`E`I.`*@*#A`)"@XP)0)>!8,(WE7$"-Y09PH.$`
M0*#C!6"@X0!0H.,(@(WE#)"-Y5"@C>(`!IKH!8"@X0>@*N`$<*#A!I`IX(`!
MC>@HP)WE6'"-XL``E^@,8);@!H"@X2$QH.$!7Z#A"""-X@8`DN@@487A`\"%
MX8(RH.$$,(WE!#"=Y:$]@^%0D(WE5*"-Y00PC>6!,J#A`#"-Y5`PG>4`3Z#A
M`P"8X*%MH.$`@*#A,!"-X@,`D>@%L(3A&`"=Z`Q`@>$`$*#C@F*&X08P@^$#
M8*#A"S"`X0,@H.$$,*#A,`"-Y300C>4+`*#A`!"@XP:`F.`(<(WBP`"7Z`)@
M!N`#<`?@:E^-XC``E>C``(WH]G]/XL``E^@$8);@!D"@X5BPC>5<P(WE,'"-
MXL``E^A0`(WE5!"-Y0``H.,`$*#C"*"@X4"`G>4+8`;@`+"@XPB0E.`P`)WH
M`7"@X09`A.$`8*#A**"-Y2RPC>4)L*#A")"-X@`#F>@)'Z#A*!&!X0@/H.$I
M,:#A!H"@X0>0H.$``XWH`Y"!X2@PC>(,`)/H`8"`X:(=H.$`$(WEHQV@X000
MC>6#<J#A!!";X%C`C>(`&)SHHGV'X8)BH.$!(*#A"+"+X0L`H.$`<(WE`'"@
MXS``G>@&0(3A!&"2X"A`C>(8`)3H"<",X0`P`^`,0`3@&`"-Z!N^C>(`#)OH
M\5^/XC``E>A8@(WE7)"-Y0>0H.$*0)3@"U"EX`2@H.$%L*#A``"@XP`0H.-0
M4(WB,`"5Z$"`C>5$D(WE"$`$X`:`H.$P<(WBP`"7Z`I@EN`+<*?@`!B=Z`2P
MB^$P8(WE-'"-Y0"@H.$+<*#A`;"@X2A0C>(P`)7H!1^@X201@>$$#Z#A)3&@
MX0I`H.$+4*#A`)"@XS``C>@#8('A`5"`X04`H.$&$*#A"("-Y0R0C>4(0(WB
M&`"4Z*,MH.&$LJ#A`""-Y:.]B^&D+:#A`+"-Y00@C>6#HJ#A#`"=Z%B0C>(`
M`YGH"B""X0)`H.$`@(CA`9")X0@@H.$),*#A`)"@XS!@C>)@`);H!U"5X%@`
MC>5<$(WE!("5X`A0C>(P`)7H`D`$X`-0!>`%8*#A!%"@X0D0H.%NOXWB``R;
MZ*)/C^(8`)3H"C"3X&``C>@+0*3@"&"@X0!PH.,#H*#A!+"@X4!`C>(8`)3H
M`#`#X`E`!.`$4*#A`T"@X3``C>4T$(WE``"@XP`0H.,H8(WE+'"-Y5!PC>+`
M`)?H"F"6X``&G>@$D(GA!:"*X0MPI^`)@*#A`;"@X0J0H.$`H*#A"%"-XC``
ME>@%'Z#A)!&!X00/H.$E,:#A"D"@X0M0H.$P`(WH`4"`X0-0@>$$$*#A!2"@
MX2A`C>(8`)3H"&"6X*,-H.&$LJ#A``"-Y0EPI^"CO8OAI`V@X0"PC>4$`(WE
M"&"-Y0QPC>58@(WB@`&8Z&``G>B#HJ#A`7"'X0I0A>$"@(CA`J"@X0<@H.$!
MD*#A`0"@X0`0H.,(<(WBP`"7Z`5@EN`H4(WB,`"5Z`)`!.`(4`7@,`"-Z%B0
MC>5<H(WE4D^/XA@`E.@'O8WB``R;Z`HPD^`+0*3@!+"@X3!0C>(P`)7H!H"@
MX0E`!.``D*#C`Z"@X5``C>54$(WE`5`%X```H.,`$*#C"("-Y0R0C>5`D(WB
M``.9Z`J`F.`+D*G@`!B=Z`2PB^$%P(SA0+"-Y43`C>4`H*#A`;"@X2A0C>(P
M`)7H!1^@X201@>$$#Z#A)3&@X0I`H.$+4*#A`V"!X3``C>@!4(#A!1"@X08@
MH.$(0(WB&`"4Z(2RH.&C#:#AH[V+X0``C>4`L(WEI`V@X4!@C>)@`);H!`"-
MY06`F.`P`)WH!I"IX(.BH.$H@(WE+)"-Y0I`A.$!D*#A`J"@X5B`C>*``9CH
M6)"-Y5R@C>4`D*#C`H"(X0@PH.$!`*#A`7"'X0D0H.$HD(WB``.9Z`2`F.`(
M4(WB,`"5Z`=`!.`#4`7@!6"@X010H.$#``#JW+P;CP````#<O!N/`````'*_
MC>(`#)OH&$!/XA@`E.A@`(WH"C"3X`A@H.$`<*#C"T"DX`.@H.$$L*#A4$"-
MXA@`E.@`,`/@`4`$X`10H.$#0*#A0`"-Y400C>4``*#C`!"@XRA@C>4L<(WE
M,'"-XL``E^@*8);@"W"GX``8G>@$L(OA"T"@X0"@H.$!L*#A")"-X@`#F>@)
M'Z#A*!&!X0@/H.$I,:#A"H"@X0N0H.$%P(SA#%"@X0`#C>@!@(#A`Y"!X0@0
MH.$)(*#A`,"@XRB0C>(``YGHJ#V@X8FRH.$`,(WEJ+V+X:D]H.$`L(WE!#"-
MY01@EN`8`)WH!7"GX(BBH.$(8(WE#'"-Y0HP@^%8@(WB@`&8Z`-`H.$!<(?A
M`J"@X0*`B.$'(*#A`9"@X0$`H.$,$*#A"'"-XL``E^@$8);@*%"-XC``E>@"
M0`3@"%`%X%B0C>5<H(WE,`"-Z!V^C>(`#)OH6D]/XA@`E.@*,)/@"T"DX`2P
MH.%`4(WB,`"5Z`:`H.$)0`3@`)"@XP.@H.$P`(WE-!"-Y0``H.,`$*#C"("-
MY0R0C>50<(WBP`"7Z`I@EN`,4`7@"W"GX``8G>@$L(OA"X"@X0"@H.$!L*#A
M!<",X2A0C>(P`)7H!1^@X201@>$$#Z#A)3&@X0I`H.$+4*#A#)"@X3``C>@!
M0(#A`U"!X000H.$%(*#A"&"6X`A`C>(8`)3H"7"GX%B0C>(``YGHI,V@X0&`
MB.$$P(WE`I")X0+`H.&$LJ#A"""@X0"`H..C#:#AH[V+X8.BH.$),*#A``"-
MY0"PC>4P`)WH*&"-Y2QPC>4!L*#A`6"@X0@0C>(#`)'H"'"@X2B0C>(``YGH
M"D"$X0(``.`#$`'@!("8X`%0H.$`0*#A,`"-Z`90H.%8L(WE7,"-Y2M.3^(8
M`)3H=K^-X@`,F^@*,)/@"T"DX`.@H.$$L*#A,$"-XA@`E.A08(WE5'"-Y0=`
M!.`(8*#A`'"@XP4P`^`$4*#A`T"@X0``H.,`$*#C*&"-Y2QPC>5`<(WBP`"7
MZ`I@EN``!IWH!)")X06@BN%`D(WE1*"-Y0MPI^``H*#A`;"@X0A0C>(P`)7H
M!1^@X201@>$$#Z#A)3&@X0I`H.$+4*#A,`"-Z`%`@.$$@*#A`U"!X2A`C>(8
M`)3HHRV@X060H.$`((WEA+*@X:0MH.%`4(WB,`"5Z`1@EN`%<*?@"&"-Y0QP
MC>4(<*#AH[V+X0"PC>4$((WE@Z*@X0P`G>@)@*#A"B""X5@0C>(#`)'H`D"@
MX0<`@.$)$('A`""@X0$PH.$`$*#C!P"@X5APC>5<@(WE"'"-XL``E^@$8);@
M*%"-XC``E>@"0`3@`U`%X#``C>@>OHWB``R;Z/%/C^(8`)3H!H"@X0"0H.,*
M,)/@"T"DX`.@H.$$L*#A`2"@X5!0C>(P`)7H0`"-Y400C>4`0`3@`!"@XP``
MH.,(@(WE#)"-Y3"0C>(``YGH"H"8X`N0J>``&)WH`E`%X`2PB^$%P(SA,+"-
MY33`C>4`H*#A`;"@X2A0C>(P`)7H!1^@X201@>$$#Z#A)3&@X0I`H.$+4*#A
M,`"-Z`%0@.$#8('A!1"@X0A`C>(8`)3HHPV@X82RH.$``(WEH[V+X8.BH.&D
M#:#A,$"-XA@`E.@`L(WE!`"-Y0.`F.`$D*G@,`"=Z"B`C>4LD(WE"D"$X0&0
MH.$&H*#A6("-XH`!F.@&@(CA"#"@X5B0C>5<H(WE*)"-X@`#F>@$@)C@"%"-
MXC``E>@!<(?A!T`$X`-0!>`%8*#A!%"@X0$`H.$`$*#C>K^-X@`,F^B?3X_B
M&`"4Z&``C>@*,)/@"&"@X0!PH.,+0*3@`Z"@X02PH.%`0(WB&`"4Z``P`^`!
M0`3@!%"@X0-`H.$P`(WE-!"-Y0``H.,`$*#C*&"-Y2QPC>50<(WBP`"7Z`I@
MEN`+<*?@`!B=Z`2PB^$+0*#A`*"@X0&PH.$(D(WB``.9Z`D?H.$H$8'A"`^@
MX2DQH.$*@*#A"Y"@X07`C.$,4*#A``.-Z`&`@.$#D('A"!"@X0D@H.$`P*#C
M*)"-X@`#F>BH/:#AB;*@X0`PC>6HO8OAJ3V@X0"PC>4$,(WE!&"6X!@`G>@%
M<*?@B**@X0A@C>4,<(WE"C"#X5B`C>*``9CH`T"@X0%PA^$"H*#A`H"(X0<@
MH.$!D*#A`0"@X0P0H.$(<(WBP`"7Z`1@EN`H4(WB,`"5Z`)`!.`(4`7@,`"-
MZ%B0C>5<H(WE34^/XA@`E.@?OHWB``R;Z`HPD^`+0*3@`Z"@X02PH.$P4(WB
M,`"5Z%``C>54$(WE"4`$X`:`H.$``*#C`!"@XP"0H.-`<(WBP`"7Z`I@EN`,
M4`7@"W"GX``8G>@$L(OA"("-Y0R0C>4`H*#A"X"@X0&PH.$%P(SA*%"-XC``
ME>@%'Z#A)!&!X00/H.$E,:#A"D"@X0M0H.$,D*#A,`"-Z`%`@.$#4('A!!"@
MX04@H.$(8);@"$"-XA@`E.@)<*?@6)"-X@`#F>BDS:#A`8"(X03`C>4"D(GA
M`L"@X82RH.$((*#A`("@XZ,-H.&CO8OA@Z*@X0DPH.$``(WE`+"-Y2A@C>4L
M<(WE,`"=Z`%@H.$!L*#A"!"-X@,`D>@(<*#A*)"-X@`#F>@*0(3A`@``X`,0
M`>`$@)C@`P``ZMR\&X\`````W+P;CP`````!4*#A`$"@X3``C>@&4*#A6+"-
MY5S`C>4H0$_B&`"4Z'Z_C>(`#)OH"C"3X`M`I.`#H*#A!+"@X5!`C>(8`)3H
M0&"-Y41PC>4'0`3@"&"@X0!PH.,%,`/@!%"@X0-`H.$``*#C`!"@XRA@C>4L
M<(WE,'"-XL``E^@*8);@``:=Z`20B>$%H(KA,)"-Y32@C>4+<*?@`*"@X0&P
MH.$(4(WB,`"5Z`4?H.$D$8'A!`^@X24QH.$*0*#A"U"@X3``C>@!0(#A!("@
MX0-0@>$H0(WB&`"4Z*,MH.$`((WE!9"@X:0MH.&$LJ#A,%"-XC``E>@$8);@
M!7"GX`A@C>4,<(WE"'"@X:.]B^$`L(WE!""-Y8.BH.$,`)WH"8"@X5@0C>(#
M`)'H"B""X0)`H.$'`(#A"1"!X0`@H.$!,*#A`!"@XP<`H.%8<(WE7("-Y0AP
MC>+``)?H!&"6X"A0C>(P`)7H`D`$X`-0!>`P`(WH`KR-X@`,F^AA3T_B&`"4
MZ`:`H.$`D*#C"C"3X`M`I.`#H*#A!+"@X0$@H.%`4(WB,`"5Z#``C>4T$(WE
M`$`$X``0H.,``*#C"("-Y0R0C>50D(WB``.9Z`J`F.`+D*G@`!B=Z`)0!>`$
ML(OA!<",X5"PC>54P(WE`*"@X0&PH.$H4(WB,`"5Z`4?H.$D$8'A!`^@X24Q
MH.$*0*#A"U"@X3``C>@!4(#A`V"!X040H.$(0(WB&`"4Z*,-H.&$LJ#A``"-
MY:.]B^&#HJ#AI`V@X5!`C>(8`)3H`X"8X`20J>``L(WE!`"-Y2B`C>4LD(WE
M,`"=Z`&0H.$*0(3A!J"@X5B`C>*``9CH!H"(X0@PH.%8D(WE7*"-Y2B0C>(`
M`YGH!("8X`A0C>(P`)7H`7"'X0=`!.`#4`7@!6"@X010H.$!`*#A`!"@XX*_
MC>(`#)OHLT]/XA@`E.A@`(WH"C"3X`A@H.$`<*#C"T"DX`.@H.$$L*#A,$"-
MXA@`E.@`,`/@`4`$X`10H.$#0*#A4`"-Y500C>4``*#C`!"@XRA@C>4L<(WE
M0'"-XL``E^@*8);@"W"GX``8G>@$L(OA"T"@X0"@H.$!L*#A")"-X@`#F>@)
M'Z#A*!&!X0@/H.$I,:#A"H"@X0N0H.$%P(SA#%"@X0`#C>@!@(#A`Y"!X0@0
MH.$)(*#A`,"@XRB0C>(``YGHJ#V@X8FRH.$`,(WEJ+V+X:D]H.$`L(WE!#"-
MY01@EN`8`)WH!7"GX(BBH.$(8(WE#'"-Y0HP@^%8@(WB@`&8Z`-`H.$!<(?A
M`J"@X0*`B.$'(*#A`9"@X0$`H.$,$*#A"'"-XL``E^@$8);@*%"-XC``E>@"
M0`3@"%`%X#``C>A8D(WE7*"-Y?%/C^(8`)3H(;Z-X@`,F^@*,)/@"T"DX`.@
MH.$$L*#A4%"-XC``E>A``(WE1!"-Y0E`!.`&@*#A``"@XP`0H.,`D*#C,'"-
MXL``E^@*8);@#%`%X`MPI^``&)WH!+"+X0B`C>4,D(WE`*"@X0N`H.$!L*#A
M!<",X2A0C>(P`)7H!1^@X201@>$$#Z#A)3&@X0I`H.$+4*#A#)"@X3``C>@!
M0(#A`U"!X000H.$%(*#A"&"6X`A`C>(8`)3H"7"GX%B0C>(``YGHI,V@X0&`
MB.$$P(WE`I")X0+`H.&$LJ#A"""@X0"`H..C#:#AH[V+X8.BH.$),*#A``"-
MY0"PC>4P`)WH*&"-Y2QPC>4!L*#A`6"@X0@0C>(#`)'H"'"@X2B0C>(``YGH
M"D"$X0(``.`#$`'@!("8X`%0H.$`0*#A,`"-Z`90H.%8L(WE7,"-Y9U/C^(8
M`)3HAK^-X@`,F^@*,)/@"T"DX`.@H.$$L*#A0$"-XA@`E.@P8(WE-'"-Y0=`
M!.`(8*#A`'"@XP4P`^`$4*#A`T"@X0``H.,`$*#C*&"-Y2QPC>50<(WBP`"7
MZ`I@EN``!IWH!)")X06@BN%0D(WE5*"-Y0MPI^``H*#A`;"@X0A0C>(P`)7H
M!1^@X201@>$$#Z#A)3&@X0I`H.$+4*#A,`"-Z`%`@.$$@*#A`U"!X2A`C>(8
M`)3HHRV@X060H.$`((WEA+*@X:0MH.%04(WB,`"5Z`1@EN`%<*?@"&"-Y0QP
MC>4(<*#AH[V+X0"PC>4$((WE@Z*@X0P`G>@)@*#A6!"-X@,`D>@*((+A`D"@
MX0<`@.$)$('A`""@X0$PH.$'`*#A`!"@XUAPC>5<@(WE"'"-XL``E^@$8);@
M*%"-XC``E>@"0`3@`U`%X"*^C>(`#)OH,`"-Z$9/C^(8`)3H!H"@X0"0H.,*
M,)/@"T"DX`.@H.$$L*#A,%"-XC``E>A0`(WE5!"-Y0!`!.`!4`7@``"@XP`0
MH.,(@(WE#)"-Y4"0C>(``YGH"H"8X`N0J>``&)WH!+"+X07`C.%`L(WE1,"-
MY0"@H.$!L*#A*%"-XC``E>@%'Z#A)!&!X00/H.$E,:#A"D"@X0M0H.$#8('A
M,`"-Z`%0@.$%$*#A!B"@X0A`C>(8`)3HA+*@X4!@C>)@`);HHPV@X:.]B^&D
MS:#A``"-Y03`C>4`L(WE!8"8X#``G>@&D*G@@Z*@X2B`C>4LD(WE"D"$X0&0
MH.$"H*#A6("-XH`!F.A8D(WE7*"-Y0%PA^$"@(CA`)"@XP<@H.$(,*#A`P``
MZMR\&X\`````W+P;CP`````!8*#A"!"-X@,`D>@)<*#A*)"-X@`#F>@"``#@
M`Q`!X`2`F.`!4*#A`$"@X8J_C>(`#)OH,`"-Z$A`3^(8`)3H"C"3X`M`I.`#
MH*#A!+"@X5!`C>(8`)3H0&"-Y41PC>4&,`/@!T`$X`A@H.$`<*#C!%"@X0-`
MH.$``*#C`!"@XRA@C>4L<(WE,'"-XL``E^@*8);@"W"GX``8G>@$L(OA"X"@
MX0"@H.$!L*#A!<",X0A0C>(P`)7H!1^@X201@>$$#Z#A)3&@X0I`H.$+4*#A
M#)"@X3``C>@!0(#A!`"@X0-0@>$H0(WB&`"4Z`A@EN"C+:#AA+*@X0EPI^``
M((WEH[V+X:0MH.$`L(WE!""-Y0A@C>4,<(WE6("-XH`!F.@`<(?A!1"@X0<@
MH.$`<*#C6`"-Y5P0C>4!@(CA!Q"@X3``G>@(<(WBP`"7Z(.BH.$*0(3A!&"6
MX"A0C>(P`)7H`D`$X`A0!>`P`(WH([Z-X@`,F^AA3T_B&`"4Z`:`H.%`4(WB
M,`"5Z`"0H.,*,)/@,`"-Y300C>4#H*#A`$`$X``0H.,``*#C"("-Y0R0C>50
MD(WB``.9Z`&PH.$*@)C@`*"@X<``G>@$8(;A!D"@X2APC>+``)?H!Q^@X281
M@>$&#Z#A)S&@X0I@H.$+<*#AP`"-Z`-P@>$(,(WB#`"3Z`2`F."#LJ#A`6"`
MX:*]B^&B':#A@J*@X0@@H.$`@*#C`!"-Y:,=H.$$$(WE6!"-X@,`D>A88(WE
M7'"-Y0<0@>$(<*#A`+"-Y3``G>@*0(3A!*"2X`A`C>(8`)3H!@"`X0`P`^`!
M0`3@CI^-X@`#F>@8`(WHH4]/XA@`E.@(,)/@"4"DX`.`H.$$D*#A,""-X@8`
MDN@&$`'@!R`"X`%`H.$"4*#A``"@XP`0H.-`P(WB`!B<Z`BPF^`)P*S@"X"@
MX0R0H.$`&)WH!+"+X07`C.$+0*#A#%"@X0"PH.$!P*#A4&"-Y51PC>4*8*#A
M`'"@XPA`E.`)4*7@!("@X060H.$`&(WH"+"-X@`,F^@+'Z#A*&"-Y2QPC>4J
M$8'A*S&@X0/`@>$H,(WB#`"3Z`H/H.$!L(#A@Q*@X000C>4$$)WEHAV!X000
MC>6"$J#A`!"-Y3``G>BB;:#A@V*&X09`A.$$8)C@`'"IX@:`H.$'D*#A"R"@
MX4"`C>5$D(WE`#"@XP"0H.-8$(WB`P"1Z`BPC>4,P(WE"P"`X2BPC>(`#)OH
M"5V-XC``E>@,$('A[W]/XL``E^@!L`O@`A"@X01@EN`%<*?@!D"@X0=0H.%0
M<(WBP`"7Z%@@C>5<,(WE`W`'X`@@H.$),*#A`("@XP"0H.,`H`K@`6`&X#`0
MC>(#`)'H!`"0X``,C>@%$*'@`$"@X0%0H.$#`)WH!@"`X0<0@>$P`(WE-!"-
MY0@`H.$)$*#A`P"-Z(,2H.&B'8'A`<"@X8(2H.$!L*#A*'"-XL``E^@P$(WB
M`P"1Z`>?H.$$`)#@#$"+X2;!H.$`P(WE)I&)X2?!H.$`D(WE!,"-Y0:/H.'`
M`)WH"&"&X040H>`&@*#A!&"0X`:@H.$)<(?A!Y"@X0!PH>('L*#A/AZ/X@,`
MD>B2?XWBP`"7Z`8`D.`'$*'@`7"@X0`0H.,`8*#A"@"@X0A0C>(P`)7H"("-
MY0R0C>4(0"3@"5`EX$"0C>(``YGH!(`HX`60*>`H@(WE+)"-Y:'-H.$PH(WE
M-+"-Y5"PC>(`#)OH!,"-Y2C`G>4&H)K@!["KX(&2H.$,0)K@`%"KXJ"=B>$`
MD(WE`[^@X2A`C>4L4(WE,`"=Z"*QB^&`@J#A`J^@X2-QH.$'D(OA"$"$X0N`
MBN$HL(WB``R;Z`2@FN`(4(WB,`"5Z"5^C>+``)?H*("-Y2R0C>4(0"3@"5`E
MX+Z?C^(``YGH`+"KX@:`F.`'D*G@"7"@X0"0H.,),*#A"&"@X0J`H.%`H(WE
M1+"-Y0H@H.$PH(WB``::Z`20*>`%H"K@,)"-Y32@C>584(WB,`"5Z*/-H.$$
MP(WE,,"=Y09`E."#DJ#A!U"EX*B=B>$,0)3@`;^@X0"0C>4`4*7B(+&+X0"O
MH.$A<:#A,$"-Y310C>4+`(KA,`"=Z`<0B^$`D*#A`:"@X8B"H.$P$(WB`P"1
MZ)9_C>+``)?H"$"$X8[/C^(`&)SH!`"0X``0H>(&L)O@"V"@X5``C>54$(WE
M`!"@XRA0C>(P`)7H!\"LX#"0C>4TH(WE"E`EX`QPH.%`L(WB``R;Z`C`G>4)
M0"3@!*`JX`Q`EN"!PJ#AH,V,X0Q@H.$%L"O@0*"-Y42PC>4$P(WE@,*@X0#`
MC>5`P)WE`%"GX@Q`E.``4*7B"$"-Y0Q0C>4#GZ#A,`"=Z"*1B>$"CZ#A([&@
MX0MPB>$&0(3A"6"(X0:PH.$'P*#A"*"-X@`&FN@$D)G@,$"-XA@`E.@F?HWB
MP`"7Z`LP(^`,0"3@"+"-Y0S`C>45SH_B`!B<Z`"@JN(&L)O@!\"LX`QPH.$`
MP*#C!%"@X0M@H.$#0*#A##"@X0FPH.$)(*#A0)"-Y42@C>50D(WB``.9Z"C`
MG>4$@"C@#$"6X(/"H.&KS8SA#&"@X060*>!0@(WE5)"-Y03`C>6+PJ#A`,"-
MY5#`G>4`4*?B#$"4X`!0I>(H0(WE+%"-Y0&?H.$P`)WH()&)X0"/H.$AL:#A
M!D"$X2@0C>(#`)'H"6"(X0MPB>$&@*#A!Y"@X92PC^(`#)OHFG^-XL``E^@$
M`)#@`!"AX@:@FN!0`(WE5!"-Y0I@H.$`$*#C"%"-XC``E>@PP)WE*("-Y2R0
MC>4)4"7@0*"-X@`&FN@(0"3@!["KX`20*>`,0);@@<*@X:#-C.$,8*#A!:`J
MX$"0C>5$H(WE!,"-Y8#"H.$`P(WE0,"=Y0!0J^(,0)3@`%"EX@.?H.$$``#J
M``"@X=;!8LH`````UL%BR@`````P0(WE-%"-Y2*1B>$P`)WH([&@X0MPB>$P
MP(WB`!B<Z`9`A.$"CZ#A!+";X`E@B.$&D*#A!Z"@X0#`K.)`L(WE1,"-Y0#`
MH.,H0(WB&`"4Z`DP(^`*0"3@!%"@X0-`H.$,,*#A)WZ-XL``E^@PD(WE-*"-
MY8203^(``YGH!H"8X`>0J>`)<*#A","=Y5"@C>(`!IKH!)`IX`Q`F."#PJ#A
MJ\V,X0Q@H.$%H"K@4)"-Y52@C>4$P(WEB\*@X0#`C>50P)WE`%"GX@Q`E.``
M4*7B"$"-Y0Q0C>4!GZ#A,`"=Z""1B>$`CZ#A!D"$X0E@B.$&H*#A"R"@X2&Q
MH.$+<(GA!["@X0@0C>(#`)'H"I"@X00`D.``$*'B4`"-Y500C>4`$*#C,%"-
MXC``E>@(H(WE#+"-Y0M0)>!`P(WB`!B<Z`E`).">?XWBP`"7Z`2P*^`%P"S@
M6:]/X@`&FNA`L(WE1,"-Y2C`G>4&D)G@!Z"JX`Q`F>"!PJ#AH,V,X0Q@H.$$
MP(WE@,*@X0#`C>5`P)WE`%"JX@Q`E.``4*7B*$"-Y2Q0C>4#GZ#A,`"=Z"*1
MB>$"CZ#A([&@X09`A.$+<(GA"6"(X2C`C>(`&)SH!H"@X0>0H.$$L)O@`,"L
MXD"PC>5$P(WE`,"@XPA`C>(8`)3H"GV-XL``E^@H@(WE+)"-Y0E`)."%KT_B
M``::Z`@P(^`&D)G@!%"@X0E@H.$#0*#A##"@X0>@JN`PP)WE"G"@X5"@C>(`
M!IKH!)`IX`Q`EN"#PJ#AJ\V,X0Q@H.$%H"K@4)"-Y52@C>4$P(WEB\*@X0#`
MC>50P)WE`%"GX@Q`E.``4*7B,$"-Y310C>4!GZ#A,`"=Z`L@H.$@D8GA`(^@
MX2&QH.$+<(GA!D"$X0E@B.$&D*#A!Z"@X3`0C>(#`)'H!`"0X``0H>)0`(WE
M5!"-Y0`0H.,H4(WB,`"5Z*)_C>+``)?H,)"-Y32@C>5`P(WB`!B<Z`E`).`*
M4"7@!+`KX`7`+.#!KT_B``::Z$"PC>5$P(WE","=Y0:0F>`'H*K@#$"9X('"
MH.&@S8SA#&"@X03`C>6`PJ#A`,"-Y4#`G>4`4*KB#$"4X`!0I>((0(WE#%"-
MY0.?H.$P`)WH(I&)X0*/H.$CL:#A!D"$X0MPB>$)8(CA","-X@`8G.@&@*#A
M!Y"@X02PF^``P*SB0+"-Y43`C>4`P*#C,$"-XA@`E.@I?HWBP`"7Z`B`C>4,
MD(WE"4`DX.VO3^(`!IKH"#`CX`:0F>`$4*#A"6"@X0-`H.$,,*#A!Z"JX"C`
MG>4*<*#A4*"-X@`&FN@$D"G@#$"6X(/"H.&KS8SA#&"@X06@*N!0D(WE5*"-
MY03`C>6+PJ#A`,"-Y5#`G>4`4*?B#$"4X`!0I>(H0(WE+%"-Y0&?H.$P`)WH
M"R"@X2"1B>$`CZ#A(;&@X0MPB>$&0(3A"6"(X0:0H.$'H*#A*!"-X@,`D>@$
M`)#@`!"AXE``C>54$(WE`!"@XPA0C>(P`)7HIG^-XL``E^@HD(WE+*"-Y0I0
M)>`^OH_B``R;Z`:@FN`'L*O@"W"@X4#`C>(`&)SH"4`DX`2P*^`%P"S@0+"-
MY43`C>4PP)WE#$":X('"H.&@S8SA#&"@X03`C>6`PJ#A`,"-Y4#`G>4`4*?B
M#$"4X`!0I>(P0(WE-%"-Y0.?H.$P`)WH(I&)X0*/H.$CL:#A!D"$X0MPB>$)
M8(CA,,"-X@`8G.@&@*#A!Y"@X02PF^``P*SB0+"-Y43`C>4`P*#C*$"-XA@`
ME.@J?HWBP`"7Z#"`C>4TD(WE"4`DX,:OC^(`!IKH"#`CX`:0F>`$4*#A"6"@
MX0-`H.$,,*#A!Z"JX`C`G>4*<*#A4*"-X@`&FN@$D"G@#$"6X(/"H.&KS8SA
M#&"@X06@*N!0D(WE5*"-Y03`C>6+PJ#A`,"-Y5#`G>4`4*?B#$"4X`!0I>((
M0(WE#%"-Y0&?H.$P`)WH"R"@X2"1B>$`CZ#A(;&@X0MPB>$&0(3A"6"(X0:0
MH.$'H*#A"!"-X@,`D>@$`)#@`!"AXE``C>54$(WE`!"@XS!0C>(P`)7HJG^-
MXL``E^@(D(WE#*"-Y0I0)>"/OX_B``R;Z`:@FN`'L*O@"W"@X4#`C>(`&)SH
M"4`DX`2P*^`%P"S@0+"-Y43`C>4HP)WE#$":X('"H.&@S8SA#&"@X03`C>6`
MPJ#A`,"-Y4#`G>4`4*?B#$"4X`!0I>(H0(WE+%"-Y0.?H.$P`)WH(I&)X0*/
MH.$CL:#A!D"$X0MPB>$)8(CA*,"-X@`8G.@&@*#A!Y"@X02PF^``P*SB0+"-
MY43`C>4`P*#C"$"-XA@`E.@K?HWBP`"7Z"B`C>4LD(WE"4`DX%VOC^(`!IKH
M"#`CX`:0F>`$4*#A"6"@X0-`H.$,,*#A!Z"JX`IPH.%0H(WB``::Z##`G>4$
MD"G@#$"6X(/"H.&KS8SA#&"@X06@*N!0D(WE5*"-Y03`C>6+PJ#A`,"-Y5#`
MG>4`4*?B#$"4X`!0I>(P0(WE-%"-Y0&?H.$P`)WH"R"@X2"1B>$`CZ#A(;&@
MX0MPB>$&0(3A"6"(X0:0H.$'H*#A,!"-X@,`D>@$`)#@`!"AXE``C>54$(WE
M`!"@XRA0C>(P`)7HKG^-XL``E^@PD(WE-*"-Y0I0)>"8L(_B``R;Z`:@FN`'
ML*O@"W"@X4#`C>(`&)SH"4`DX`2P*^`%P"S@0+"-Y43`C>4(P)WE#$":X('"
MH.&@S8SA#&"@X03`C>6`PJ#A`,"-Y4#`G>4`4*?B#$"4X`!0I>((0(WE#%"-
MY0.?H.$P`)WH(I&)X0*/H.$CL:#A!D"$X0MPB>$)8(CA","-X@`8G.@&@*#A
M!Y"@X00``.H``*#AUL%BR@````#6P6+*``````2PF^``P*SB0+"-Y43`C>4`
MP*#C,$"-XA@`E.@+?8WBP`"7Z`B`C>4,D(WE"4`DX$"@3^(`!IKH"#`CX`:0
MF>`$4*#A"6"@X0-`H.$,,*#A!Z"JX`IPH.$HP)WE4*"-X@`&FN@$D"G@#$"6
MX(/"H.&KS8SA#&"@X06@*N!0D(WE5*"-Y03`C>6+PJ#A`,"-Y5#`G>4`4*?B
M#$"4X`!0I>(H0(WE+%"-Y0&?H.$P`)WH"R"@X2"1B>$`CZ#A(;&@X0MPB>$&
M0(3A"6"(X0:0H.$'H*#A*!"-X@,`D>@$`)#@`!"AXE``C>54$(WE`!"@XPA0
MC>(P`)7HLG^-XL``E^@HD(WE+*"-Y0I0)>!'OT_B``R;Z`:@FN`'L*O@"W"@
MX4#`C>(`&)SH"4`DX`2P*^`%P"S@0+"-Y43`C>4PP)WE#$":X('"H.&@S8SA
M#&"@X03`C>6`PJ#A`,"-Y4#`G>4`4*?B#$"4X`!0I>(P0(WE-%"-Y0.?H.$P
M`)WH(I&)X0*/H.$CL:#A!D"$X0MPB>$)8(CA,,"-X@`8G.@&@*#A!Y"@X02P
MF^``P*SB0+"-Y43`C>4`P*#C*$"-XA@`E.@M?HWBP`"7Z#"`C>4TD(WE"4`D
MX'FO3^(`!IKH"#`CX`:0F>`$4*#A"6"@X0-`H.$,,*#A!Z"JX`C`G>4*<*#A
M4*"-X@`&FN@$D"G@#$"6X(/"H.&KS8SA#&"@X06@*N!0D(WE5*"-Y03`C>6+
MPJ#A`,"-Y5#`G>4`4*?B#$"4X`!0I>((0(WE#%"-Y0&?H.$P`)WH"R"@X2"1
MB>$`CZ#A(;&@X0MPB>$&0(3A"6"(X0:0H.$'H*#A"!"-X@,`D>@$`)#@`!"A
MXE``C>54$(WE`!"@XS!0C>(P`)7HMG^-XL``E^@(D(WE#*"-Y0I0)>`+O4_B
M``R;Z`:@FN`'L*O@"W"@X4#`C>(`&)SH"4`DX`2P*^`%P"S@0+"-Y43`C>4H
MP)WE#$":X('"H.&@S8SA#&"@X03`C>6`PJ#A`,"-Y4#`G>4`4*?B#$"4X`!0
MI>(#GZ#A*$"-Y2Q0C>4BD8GA,`"=Z".QH.$+<(GA`H^@X09`A.$'P*#A"6"(
MX2B`C>*``9CH!'"7X`>`H.$N/HWB#`"3Z-E?3^(P`)7H!K"@X0)`E.`$(*#A
M`%"@XPA`H.$HL(WE+,"-Y0APC>+``)?H,,"=Y5"0C>(``YGH"V`FX`P@DN"%
MPJ#AI,V,X0:`*.`$P(WE"("2X`R@H.&$PJ#A`,"-Y0A@H.$!SZ#A(,&,X0P@
MH.$``YWH!,"-Y0#/H.$*@(CA`,"-Y0BPEN#``)WH`F"&X3@PC>(,`)/H"R"2
MX`*@H.$0((WB!@"2Z""0C>(``YGH*#"=Y0"PH.,$$)'@`4"@X0.`F.!($(WB
M`P"1Z`@PG>4#`)#@&#"-X@P`D^@`4*#C!B"2X`"0H.,.8*#A`!"@XP`PH.,`
M#([H9,"=Y>SBG>4`P)SE#`!>X0A`AN4,4(;E&("&Y1R0AN4@`(;E)!"&Y1`@
MAN44,(;E`@``&KW?C>+P3[WH'O\OX3?J_^O8,)_E\$<MZ0!P4.(#,(_@+@``
M"L@@G^4",)/G`)"3Y0``6>,K```*`##7Y3U04^(!4*`3``!3XP!0H`,``%7C
M$P``&@!`F>4``%3C#0``"@&`H.$)8*#A!2"@X0<0H.$$`*#AH>K_ZP``4.,"
M```:!3#4YST`4^,,```*!$"VY0``5./S__\:!`"@X?!'O>@>_R_A!U"@X0$P
M]>4``%/C/0!3$_O__QH'4$7@Y/__Z@E@1N!&8:#A`5"%X@!@B.4%0(3@!`"@
MX?!'O>@>_R_A!T"@X>O__^H)0*#AZ?__ZOQC`0!,`0``\$`MZ0S03>(`4*#A
M#4"@X8!PG^6`,)_E!W"/X`-@E^<`,);E!#"-Y000H.$%`*#AN/__ZP``4.,.
M```*7#"?Y0,PE^<`$)WE`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@
MD^4``%+C!""#Y/O__QKK___J!""=Y0`PEN4#`%+A`@``&@S0C>+P0+WH'O\O
MX=?I_^L(8P$`&`$``$P!``#P3RWI`4"@X0R2G^4,,I_E`"#1Y0F0C^`#8)GG
M/0!2XP%`@0(`,);E%-!-X@!0H.$$`*#A##"-Y0'J_^L($(WB`'"@X04`H.&)
M___K`(!0XC\```KZZ?_K!P!0X38``"J\,9_E"("=Y0.0F><(@:#A`##5Y3T`
M4^(!`*`3``!3XP``H`,``%#C!0``"@4`H.$!,/#E``!3XST`4Q/[__\:!0!`
MX`)PA^(``(?@`'"9Y='I_^L``%#C"`"'YU,```H`,-7E/0!3XP``4Q,`()GE
M"!"=Y0$1DN<!`(7B`##!Y08```H!(('B`3#0Y```4^,]`%,3`A"@X0$PPN3Y
M__\:/3"@XP$@H.$`,,'E`3#4Y```4^,!,.+E^___&@``H.,,()WE`#"6Y0,`
M4N$Y```:%-"-XO!/O>@>_R_A`3!(X@$@U.0``%+C`2#CY?O__QKQ___JR#"?
MY0.0F><`L)GE`*";Y0``6N,($*`#"0``"@@PH.$+(*#A````Z@HPH.$$$++E
M``!1XP&@@^+Z__\:`S"#X@,1H.&(,)_E`S"/X``@D^4``%+C$0``&@$@H.,!
M`*#A`""#Y8_I_^L`,%#B!#"-Y1$```H*@:#A"Q"@X0@@H.%&Z?_K!#"=Y0`P
MB>4`$*#C`2"*X@(1@^<(H(WEGO__Z@L`H.%>Z?_K``!0XP`PH.$``(GE"H&@
M$?/__QH``.#CP?__ZDWI_^MH8@$`&`$``$P!``!T8@$`\$,MZ2PQG^4L(9_E
M`S"/X`)`D^<`,)3E?-!-X@!04.)T,(WE`@``"@`PU>4``%/C!@``&G0@G>4`
M,)3E`P!2X3L``!I\T(WB\$.]Z![_+^%8Z?_K`'!0XO7__PK<@)_E"("/X`<`
MH.&FZ?_K``!0XR@```H3,-#E+C!SX@4``!H4,-#E``!3X_7__PHN,'/B%3#0
M!0`P8P(``%/C\/__"A-@@.(%`*#A6NG_ZP"0H.$&`*#A5^G_ZP``B>`"`(#B
M0NG_ZP"0H.$(,*#A`"#@XP$0H.-@`(WH7>G_ZPD0H.$(((WB`P"@XX_I_^L!
M`'#C"0"@X0,```H8,)WE#SH#X@$)4^,(```*#.G_ZPD`H.'OZ/_KTO__Z@<`
MH.&1Z?_K!0"@X?/H_^O!___JL___Z_7__^K[Z/_K1&`!`!@!``"0'```<$`M
MZ80PG^6$()_E`S"/X`)`D^<`4*#A``"4Y8/I_^L%$*#A4B^`X@,`H.-YZ?_K
M``!0XP(```H``*#C<$"]Z![_+^$``)3E>.G_ZU@QD.4/.@/B`0E3XP4```H`
M`)3E<NG_ZU@QD.4/.@/B"@I3X_#__QH%`*#A`A"@XT?I_^L!`'#B``"@,W!`
MO>@>_R_A`%\!`"`!``#P1RWI_$"?Y?PPG^4$0(_@`X"4YP':3>((T$WB`)"@
MX>@`G^4`,)CE`<J-X@1@C>($P(SB`:"@X=0@G^4&$*#A``"/X``PC.71Z/_K
M``!0XR<``-H(4(WB`7!`X@=0A>"P,)_E!"!5Y0,PE.<``%+C`$"3Y18```H`
M<*#A!R"@X2\0H.,&`*#A&^G_ZP``4.,1```*!`"@X3[I_^L',*#A!B"@X0D0
MH.$BZ?_K`3J-X@0P@^(`()/E`#"8Y0,`4N$/```:`=J-X@C0C>+P1[WH'O\O
MX0``5^/G__\:!`"@X2SI_^L*(*#A"1"@X:7H_^OM___J'#"?Y0,PE.<`0)/E
M]?__ZI#H_^MH7@$`&`$``-P:``#_#P``(`$``!!`+>DT0)_E-#"?Y01`C^`#
M,)3G``"3Y1?I_^LD,)_E)!"?Y0,@E.<@,)_E`1"/X`,PC^#1Z/_K$$"]Z![_
M+^%,70$`(`$``!P!``#D&0``F!D``!!`+>E4,)_E5""?Y0,PC^`"0)/G"-!-
MX@``E.4!Z?_KX?__ZP``E.7^Z/_K`""@XS`PG^4$((WE+!"?Y2P@G^4#,(_@
M`#"-Y0(@C^`!$(_@RNC_ZPC0C>(00+WH'O\OX?A<`0`@`0``:!P``(P9``#8
M$P``\$`MZ<@PG^7(()_E`S"/X`)0D^<"VDWB'-!-X@`PE>4"*HWB%"""X@`P
M@N6#Z/_KI#"?Y0,PC^`)`(WHG#"?Y0Q`C>(!:HWB!`"@X0,PC^",()_E`1"@
MXQ!@AN*,Z/_K!`"@X080H.$!*J#C3^C_ZP!`4.(3``"Z`0"$XF/H_^L`<%#B
M!```"@80H.$$(*#A)>C_ZP`PH.,$,,?G`CJ-XA0P@^(`()/E`#"5Y0,`4N$'
M`*#A!0``&@+:C>(<T(WB\$"]Z![_+^$`<*#C\O__ZB3H_^N$7`$`&`$``%09
M```P&0```1```,3__^KP3RWI6(*?Y5@RG^4(@(_@`S"8YP':3>(LT$WB`$"@
MX40"G^44,(WE`2J-X@`PD^4HD(WB)"""X@%0H.$``(_@"!!)X@`P@N73_?_K
M+Q"@XP!@H.$$`*#A2>C_ZP``4.,/```*!`*?Y000H.$``(_@+/[_ZP0`H.$!
M.HWB)#"#X@`@D^44,)WE`#"3Y0,`4N%R```:`=J-XBS0C>+P3[WH'O\OX00`
MH.$OZ/_KP!&?Y0"PH.$!$(_@!0"@X6#H_^L`<%#BYO__"J@QG^4#,(_@&#"-
MY:`QG^4#,(_@'#"-Y0`PU^4``%/CD*&?Y3T```H``%;C!```"@<0H.$&`*#A
MMN?_ZP``4.,_```*!P"@X17H_^L!,$#B`R#7YR\`4N,#,(?@!0``&@`0H.,`
M$,/E`2!SY2\`4N,!`$#B^O__"@$PB^(``(/@"@!0X<3__\HL,9_E`S"/X`0P
MC>4D,9_E!%!)X@$JH.,!$*#C`'"-Y0,PC^`(0(WE!0"@X0GH_^L$,9_E`W"8
MYP``E^5-Z/_K!1"@X5(O@.(#`*#C-^C_ZP``4.,%```:``"7Y47H_^M8,9#E
M#SH#X@()4^,;```*R!"?Y0``H.,!$(_@'.C_ZP!PH.$``%?CH?__"@`PU^4`
M`%/CP?__&@``5N,,```*&!"=Y08`H.%XY__K``!0XQAPG14!`*`3S/__&H`0
MG^4``*#C`1"/X`GH_^L`<*#AZ___ZAQPG>4!`*#CP___Z@$0H.,%`*#A_N?_
MZP``4./>__\:3`"?Y040H.$``(_@M/W_ZP4`H.'8Y__KA?__ZH7G_^N86P$`
M&`$``&@8``!$&```#!@``-07``#(%P``_P\``'@7``!4%P``(`$``/@6``"L
M%@``9!8````@T.4``%+C'O\O`0$P@.(O`%+C`P"@`0$@T^0``%+C^O__&A[_
M+^%P0"WI`$!0XAL```H`4-3E``!5XQ@```JBY__K`0!`X@`@A.`"`%3A"P``
M*@`PU.<O`%/C,P``&@$P0N(#``#J`!#3Y2\`4>,!,$/B+0``&@0`4^$#(*#A
M^/__&@(`5.$1```:+P!5XP,```K$`)_E``"/X*#G_^L&``#J`@"@XW;G_^L`
M,%#B!```"BX@H.,#`*#AL"##X7!`O>@>_R_A``"@XW!`O>@>_R_A`2!"X@0`
M`.H`,-+E+P!3XP$P0N("```:`R"@X0(`5.'X__\Z!"!"X`(P@N(!"E/C[___
MBE0`G^4``(_@!!"@X0!`H.$!((+B`3J@XROG_^L$`*#A<$"]Z![_+^$!,$+B
M`P``Z@`0T^4O`%'C`3!#XN+__PH#`%3A`R"@X?C__SH"`%3AR___"MS__^J8
M%0``I%D!`'!`+>FTP9_E#,"/X`S`C.*L49_E,-!-X@\`O.BD09_E!5"/X`C@
MC>($4)7G#P"NZ`\`O.@/`*[HC`&?Y0`@G.4`,)7E``"/X+`@SN$L,(WE"OW_
MZW0!G^4``(_@!_W_ZVP!G^4``(_@!/W_ZV0!G^4``(_@`?W_ZUP!G^4``(_@
M_OS_ZU0!G^4``(_@^_S_ZTP!G^4``(_@^/S_ZT1AG^5$`9_E!F"/X```C^#S
M_/_K!@"@X?'\_^LP`9_E``"/X.[\_^LH`9_E``"/X.O\_^L@`9_E!$"-X@00
MH.$``(_@K/S_ZP`04.(&`*`1#/W_&P0!G^4$$*#A``"/X*7\_^L`$%#B]`"?
M%0``CQ`$_?\;[`"?Y000H.$``(_@G?S_ZP`04.(.```*V`"?Y0``C^#[_/_K
MT!"?Y=``G^4!$(_@``"/X/;\_^LL()WE`#"5Y0,`4N$8```:,-"-XG!`O>@>
M_R_AJ`"?Y000H.$``(_@B/S_ZP`04.(+```:E!"?Y0H@H.,!$(_@&0"-XCWG
M_^L``%#CYO__&GP`G^4C$(WB``"/X-[\_^OA___J;`"?Y0``C^#:_/_KW?__
MZJWF_^L(%```@%<!`!@!``"(%```@!0``'P4``!\%```>!0``'P4```,%```
M>!0``&@4``!L%```Y!,``%@4``!0%```5!0``%`4``!T$P``7!0``+03```,
M%```"!0``'`3``!@$P``$$`MZ800G^6$()_EA#"?Y0$0C^`#,(_@`D"1YP``
MD^4`,)3E"-!-X@$`<.,$,(WE!@``"@0@G>4`,)3E`P!2X1$``!H(T(WB$$"]
MZ![_+^%$`)_E#1"@X0``C^!$_/_K``!0XP0```H``-#E,`!0XP``4!,!`*`3
M``"@`QPPG^4#,(_@``"#Y>G__^IPYO_K;%4!`!@!``#`5@$`E!(``%16`0`0
M0"WI3N;_ZT?F_^L``%#C``"0%1!`O>@>_R_A\$$MZ=@PG^78()_E`S"/X`)`
MD^?08)_E&-!-X@`PE.4&8(_@`%"@X1`0C>(&`*#A%#"-Y1[\_^L`<%#B!1"@
MX1P```H`,-?E``!3XQD```HEYO_K``!0XQD``!H%`*#AA^;_ZP"`H.$'`*#A
MA.;_ZP``B.`"`(#B;^;_ZP"`H.%H,)_E`S"/X`0PC>5@,)_E"'"-Y0!0C>4#
M,(_@`"#@XP$0H..%YO_K"!"@X08`H.%B_/_K`@``ZC@`G^4``(_@7OS_ZQ0@
MG>4`,)3E`P!2X0(``!H8T(WB\$&]Z![_+^$KYO_KL%0!`!@!``"8$@``5!$`
M`$01``#\$0``\$\MZ8S)G^6!W$WB/-!-X@S`C^"`F9_E3E^-XGSIG^4`@*#A
M!P"<Z0F0C^#X,$7B$$",X@Y@F><'`(/H#P"TZ.#@1>(/`*[H`P"4Z"C`C.(#
M`([H!P"<Z.PP1>('`(/H/`F?Y0#`EN4@8(WE@3R-XOQ@1>(T,(/B!A"@X0``
MC^``P(/ER_O_ZP!`4.("```*`##4Y0``4^,``0`:D?__ZP!P4.("`0`*!P"@
MX37F_^N``*#A`0"`XB#F_^L`,-?E``!3XP"@H.$,```*"D"@X="XG^4+L(_@
M`#"-Y00`H.$+,*#A`"#@XP$0H.,TYO_K`3#WY0``4^,"0(3B]?__&N``%>4`
M`%#C$@``"MQ`1>("``#J!`"4Y```4.,-```*!A"@X:/[_^L`<%#B^/__"@`P
MU^4``%/C]?__"MS\_^L``%#C\O__"@<`H.$BYO_K`$!0XA<``!H`L*#C^'!%
MX@LQA>#X0!/E``!4XPH```H`,-3E``!3XP<```H$`*#AR_S_ZP``4.,!L(OB
M!```&@M!E^<``%3C]/__&@!`H.,$``#J!`"@X0OF_^L``%#CZO__"@!`H.$$
M`*#A\>7_ZP!PH.$*`*#A[N7_ZP!PA^`!>X?B!'"'X@<`H.'7Y?_K`+"@X<`W
MG^7`)Y_E`S"/X`0PC>6X-Y_E`B"/X`@@C>4#,(_@`"#@XP$0H.,,H(WE`$"-
MY>KE_^L+`*#A!QV@X_/E_^L!`'#C`P``&N'E_^L`()#E$0!2X_8!`!IT-Y_E
M`Z"9YP``FN4EYO_K"Q"@X5(O@.(#`*#C&^;_ZP!`4.(5```*F#>?Y0,@F><`
M`)+E1">?Y0`PF.4"((_@`+"-Y0$0H./IY?_K`*"@XX$\C>(T,(/B`""3Y2`P
MG>4`,)/E`P!2X0H`H.$,`@`:@=R-XCS0C>+P3[WH'O\OX0``FN4'YO_K6#&0
MY0\Z`^(!"5/CX___&@``FN4!YO_K8#&0Y1@PC>50Y?_K&#"=Y0``4^';__\:
M``":Y?GE_^M8,9#E@SN@X:,[H.$'#5/CU/__&@<`H.&)Y?_K`*"@X9P&G^4&
M$*#A``"/X"+[_^L``%#C>```"@!@F.6GY?_K`!"@X08`H.$T_?_K`&!0XG$`
M``H&`*#AB^7_ZP,`4.,`<*#A#```FE@6G^4$`$#B``"&X`$0C^`@Y?_K``!0
MXP4``!H$`%?C7@$`"@=PAN`%,%?E+P!3XUH!``JI_O_K`!!0X@0``!H&`*#A
M8>7_ZP`P4.(H,(WE60``&@@6G^4(!I_E`1"/X```C^!=^__K9^7_Z_@UG^7X
M)9_E`S"/X`0PC>7P-9_E`B"/X.R%G^7L=9_E[&6?Y0@`C>4,((WE`+"-Y0,P
MC^``(.#C`1"@XPH`H.%KY?_K"("/X`=PC^`&8(_@#P``ZF/E_^L`,)#E$0!3
MXQ$``!I-Y?_K`4"$X@@`C>4,0(WE$'"-Y01@C>4`L(WE!2"@X0@PH.$!$*#C
M"@"@X5?E_^L'':#C"@"@X6#E_^L!`'#C`%"@X>G__PH+`*#A[^3_ZUP%G^4*
M$*#A``"/X"O[_^L*`*#AF?[_ZWK__^J7_O_K!`"@X4OE_^L`H*#A=?__Z@=`
MH.%,H(WB!`&:YP``4.,,```*!A"@X;GZ_^L`,%#B`4"$XO?__PH`,-/E``!3
MX_3__PH[Y?_K``!0X_'__PH`<*#AZO[_Z@T`H.,.Y?_KX'2?Y0"@H.$'<(_@
M4S"@X^S^_^H`8)CEB___Z@001>("0*#C`6"@X0`PX.,1(.#C`$"-Y200C>7S
MY/_K!A"@X08@H.,H`)WEL^3_ZP0P5>4``%/C`@``&@,P5>5#`%/C-P$`"@!`
MH.,`(*#C`#"@XP!`C>4H`)WEX^3_ZP`@H.,`,*#C/AZ/X@,`D>@^?H_BP`"7
MZ*`@!>6<,`7EF"`%Y90P!>7```7EO!`%Y?(_C^(,`)/H\A^/X@,`D>C(8`7E
MQ'`%Y;@@!>6T,`7E[G^/XL``E^AP,(WBJ``%Y:00!>500`7E+#"-Y3"@C>4T
ML(WEL&`%Y:QP!>608$7B`BF@XR00G>4H`)WE@^3_ZP!`4.).``#:`+"@XZ`0
M1>(#`)'HA*&@X0`@FN`+`%'A`@!0`02`H.'$GZ#A`J"@X9@01>(#`)'H`0``
MF@$`D.(`$*'BJ#Z@X8DQ@^$8,(WEJ3Z@X1PPC>48,(WB#`"3Z``@DN!0`!7E
M`3"CX```4..@H`7EG+`%Y9@@!>64,`7E+0``"D"`8.((`%3A!("@L0``AN`(
M(*#A)!"=Y6KD_^M0,!7E`S"(X$``4^-0,`7ESO__&B0PG>4L`)WE"$!$X`B`
M@^`+YO_K/P!4XQ,``-I`0$3B/Y#$XX`PB.(L<)WE`Y")X$"@B.)`(*#C0!!*
MX@8`H.$"H(K@4^3_ZP<`H.'\Y?_K"0!:X?;__QHD,Z#A`2"#X@,]8^`"@XC@
M`T.$X`@0H.%(,*#C!""@X08`H.%IY/_K4$`%Y:S__^HD@)WEX/__ZC"@C>(H
M`)WE``R:Z-;D_^M_(.#CH&`5Y:8QH.$_,`/B`1"#XI!`1>(X`%'CF'`5Y0,@
MQ.=L``#*`0"$X#@@8>(`$*#CF.3_ZR<LH.$G.*#A+`"=Y55P1>518$7E)W2@
MX5@@1>57,$7E)BR@X28XH.$F9*#A5G!%Y50@1>53,$7E4F!%Y<KE_^O(P!7E
MP``5Y2SHH.$L/*#A0<!%Y2S$H.&X$!7E0L!%Y2#,H.$]`$7E0,!%Y2#(H.$@
M!*#AL"`5Y3X`1>4A#*#A0^!%Y3D01>6HX!7E/`!%Y2$(H.$A%*#A.P!%Y3H0
M1>4B#*#A(AB@X34@1>6@D9_E(B2@X3"`1>(X`$7E-Q!%Y2X,H.$N&*#A-B!%
MY2XDH.$(0*#A1#!%Y3_`1>4QX$7E-`!%Y3,01>4R($7E"9"/X$1@1>((<$7B
M````Z@$P]N4`,(WE!`"@X0DPH.$`(.#C`1"@XP)`A.)"Y/_K!`!7X?7__QH`
M`*#C*#&?Y2@AG^4#,(_@!#"-Y2`QG^4"((_@#""-Y0B`C>4`L(WE`S"/X`@`
M1>4`(.#C`1"@XPH`H.$PY/_KW?[_Z@1PF.4``%?CH?[_"@<`H.$;Y/_K`P!0
MXYW^_YK8$)_E!`!`X@``A^`!$(_@L>/_ZP``4.,'8*`!E?[_ZD`@8>(!`(3@
M`!"@XROD_^LL`)WE:^7_ZP0`H.$X(*#C`!"@XR7D_^N+___J``"@X8FKS>\`
M`````2-%9P````#^W+J8`````/#ATL,`````=E0R$``````(50$`F%,!`!@!
M``!$$````!$``/P.``#P#P``W`\``"`!``"\#P``"`\``!@/``#X#0``;`T`
M`!`-``"`#P``J`X``*0.``!,#P``S`P``#0,``#`#```3`D``!P(``","@``
ML`D``&0)```H`0``O`<``#P&``"L"```T`<``!PP'^4#$)GG`#"8Y0``D>4$
M((WE+"`?Y0"PC>4"((_@`1"@X_OC_^L`H*#C$/[_Z@(P5>5!`%/CQ/[_&@$P
M5>5#`%/CP?[_&@`PU>5(`%/COO[_&@$PU>5%`%/CN_[_&@!`C>4H0)WE`##@
MXSD@X.,$`*#AG^/_ZP0`H.$D0)WE*2"@XP00H.%>X__KH#`?Y:`@'^4#,(_@
M!#"-Y:@P'^4"((_@#""-Y0A`C>4`L(WE`S"/X``@X.,!$*#C"@"@X;GC_^MF
M_O_J;./_Z_!/+>F\(Y_EO#.?Y0(@C^`#,)+G`!"3Y1S03>(4$(WE##"-Y:0S
MG^4#0)+G``"4Y?+C_^L`4*#A``"4Y>_C_^MH,-7E:3#`Y80#G^40$(WB``"/
MX`@0C>4=^?_K``!0XP(```H`,-#E,0!3X[,```HQ_/_K``"4Y>#C_^M4$Y_E
M"S"@XP$@H.,!$(_@>./_ZP``4.-*```*/#.?Y0,PC^`$()/E$#"0Y0$`4N,8
M@)/E`)"4Y4,``-H@,Y_E(+.?Y0,PC^``8*#C`5"@XPNPC^`0HY_E`#"-Y0EP
MH.$*``#J$!"1Y0D`H.$*X__K`#"=Y0``4.,$()/E'@``&@%0A>(%`%+A`6"&
MXAH``-H'`*#ANN/_ZP8@H.$`,*#C"!"@X9CC_^L`(%#BB```"@`0DN4(,)'E
M"`";Y0HP`^`!"U/C!9&0YP!PE.7D__\*!P"@X00@C>6IX__K!""=Y0(PH.,`
M$)+E`""@XRGC_^L`<)3E`!"@X=K__^H'D*#A`1!"X@8`4>$/```:`0!2XPT`
M`-I48I_E`5"@XP9@C^`)`*#A````Z@``E.64X__K"!"@X>WB_^L$,);E`5"%
MX@4`4^'W___*`)"4Y0D`H.&+X__K&!*?Y0,PH.,!(*#C`1"/X"/C_^L`4%#B
M"P``"@``E.6"X__K$#"5Y?0AG^4`$)/E`B"/X/GB_^L0,)7E`#"3Y0@PD^4!
M!1/C6@``&@``E.5VX__KS!&?Y0,PH.,!(*#C`1"/X`[C_^L`4%#B"P``"K0!
MG^4($)WE``"/X*#X_^L`8%#B``"4Y4$```IGX__K$#"5Y08@H.$`$)/EW^+_
MZP``E.5AX__K`%"@X0``E.5>X__K=!&?Y0$@H.,!$(_@#./_ZV@AG^4`$*#A
M`B"/X`4`H.'1XO_K``"4Y5/C_^L`,*#C:3#`Y4@!G^4($)WE``"/X(+X_^L\
M49_E``!0XP50C^``0*#A#`"%Y0X```H'':#C!`"@X0CC_^L!,(#B$0!0XP$`
M4Q,I``"*##"=Y10@G>4`,)/E`P!2X2,``!H<T(WB\$^]Z![_+^$(`)7E??S_
MZP``4.,`0*#A#`"%Y>K__QK4`)_E``"/X.KB_^L!,-#E``!3XTG__PI'___J
MO""?Y0(@C^``D)3E!""2Y87__^HEX__KJ#"?Y0,PC^`0()7E"#"3Y0``DN4`
M$)/EN/G_Z[G__^H``)3E&^/_ZQ`PE>4`$)/EY>+_ZY[__^J#XO_K<#"?Y0,P
MC^`($)/E`#"@X60`G^4$(*#A`!"1Y0``C^#(XO_KT$@!`!@!```@`0``X`4`
M`&`'``#420$`L$D!`*1)`0``!"``V$@!`!0&``#T!0``Z`4``*`#``!P!0``
M>`4``!P#``"@1P$`Y`0``!Q'`0`$1P$`R$8!`(`$``!P0"WI`%"@X?+Z_^L`
M,-#E``!3XP!`H.$%```*`2"`XB\`4^,"0*`!`3#2Y```4^/Z__\:P/O_ZP``
M5>,``%`3`0``&G!`O>@>_R_A`##5Y0``4^/Z__\*(!"?Y00`H.$$(*#C`1"/
MX,SB_^L``%#C\___&@4`H.%P0+WH^?C_ZGP"```00"WI'#"?Y1S`G^4#,(_@
M##"3YP``4^,`,),5/>+_ZQ!`O>@>_R_A*$0!`#`!``#P1RWI5&"?Y510G^4&
M8(_@!5"/X`5@1N``<*#A`8"@X0*0H.'YX?_K1F&PX0D```H`0*#C`4"$X@0P
ME>0)(*#A"!"@X0<`H.$/X*#A$_\OX00`5N'V__\:\$>]Z![_+^',0@$`Q$(!
M`![_+^$(0"WI"$"]Z![_+^$!``(`<&5R;'AS:2YC````7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("``````)7,O)7,````O<')O8R]S96QF+V5X
M90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2
M.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%2
M7U!23T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!015),
M3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]3
M4$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!
M4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U0
M1$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?
M0TQ%04X]```Q````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E
M<R5S)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``%!!5$@`````)7,Z
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E
M;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``<&%R;``````N
M<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E
M;7`M)74M)74E<P````!!4D=6`````!@```!P97)L`````%!!4CHZ4&%C:V5R
M.CI615)324].`````#$N,#0P````56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``%53
M15(`````55-%4DY!344`````5$5-4$1)4@!435``+W1M<`````!E=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P[
M"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A
M<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M
M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N
M86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M
M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L
M;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF
M:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P
M87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-
M4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@
M(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S
M971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O
M<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![
M?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H
M7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O
M9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E
M="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F
M<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@
M)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE
M('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N
M<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP
M;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@
M?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T
M('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@
M7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(
M+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@
M)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U
M:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM
M>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D
M9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH
M6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L
M("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\
M<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R
M8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@
M/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@
M>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D
M8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS
M92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^
M("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F
M+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE
M*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY
M("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\
M(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2![
M"FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0[
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y
M*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL
M96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F
M:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*
M?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M
M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G
M/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D
M(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.
M0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL
M93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?
M;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N
M86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*
M?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL
M97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@
M)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D55
M4T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B
M;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A
M)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F
M('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R
M"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P
M87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E
M<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]21553
M17T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA
M=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP
M72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H
M)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G
M*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G
M*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@
M/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L
M;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF
M("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B
M6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G
M*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@
M)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0
M)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D
M9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'
M5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D
M<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H
M)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G
M)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A
M;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD
M;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,[
M"B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D
M+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P
M87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R
M(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP
M,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?
M5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@
M/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A
M9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD
M=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC
M(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@
M(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA
M9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@
M+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*
M)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D[
M"G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.
M+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[
M)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L
M=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E
M>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@
M>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2![
M"FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F
M:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C
M72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]
M"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H
M;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B
M)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO
M="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q
M*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL
M92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L
M("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I
M;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q
M*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^
M<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U
M=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I
M.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A
M)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@
M>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S
M=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N
M(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D
M<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS
M.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE
M;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB
M:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M
M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN
M(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H
M*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A
M.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0
M?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@
M8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG
M.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*
M;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?
M5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q
M*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*
M979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R
M.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S
M="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!]
M.PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L
M87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T
M96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]
M"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-
M4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0
M("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M
M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED
M.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^
M.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R
M;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P
M=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M
M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<[
M"GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T
M:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@
M*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS
M>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B
M*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*
M)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@
M;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P
M<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N
M9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^
M:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*
M)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\[
M"GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D
M92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N
M;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA
M;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C
M86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT
M("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP
M;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L
M;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA
M;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I
M('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%
M3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%
M35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE
M?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N
M9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I
M;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@
M*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O
M;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF
M;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!
M4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]4
M14U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI
M<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B
M<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM0
M05)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI
M+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F
M:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<
M;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`
M24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q
M=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E
M>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA
M:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A
M<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N
M)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE
M(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O
M9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF
M("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/
M4CL*,3L*7U]%3D1?7PH`N$W_?P$`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````[!D``(09```!`````0````$```#+`0```0```-8!```!````X`$```$`
M```O`@```0```(H#```!````J@,```P```"T$@``#0```!"+```9````@,T!
M`!L````$````&@```(3-`0`<````!````/7^_V^L`0``!0```'@)```&````
MF`(```H````.!0``"P```!`````5``````````,```"PS@$``@`````"```4
M````$0```!<```"T$```$0```,0/```2````\````!,````(````'@````@`
M``#[__]O`0``"/[__V]D#P``____;P,```#P__]OA@X``/K__V\1````````
M`````````````````````````````````````````````````(C-`0``````
M`````,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$
M$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02
M``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(`
M`,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``
MQ!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$
M$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02```,BP``````````
M```````````````````````````````````$T`$``````*2*````````V!4`
M```````````````````````$T`$`_____X".``"LBP```````&R,``!PC```
M=(X``+2+``!\C@```````&".``!HC@```````(B.``!'0T,Z("A$96)I86X@
M-RXR+C`M,3$I(#<N,BXP`$=#0SH@*$1E8FEA;B`V+C0N,"TT*2`V+C0N,"`R
M,#$W,#@R,`!!*0```&%E86)I``$?````!314``8""`$)`1($$P$4`14!%P,8
M`1D!&@(`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG
M;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E
M<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`
M+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X`"YE:%]F<F%M90`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`
M+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````````````
M```````````````````````````````+`````0````(```!4`0``5`$``!,`
M``````````````$`````````$P````<````"````:`$``&@!```@````````
M```````$`````````"$````'`````@```(@!``"(`0``)```````````````
M!``````````T````]O__;P(```"L`0``K`$``.P````%``````````0````$
M````/@````L````"````F`(``)@"``#@!@``!@````,````$````$````$8`
M```#`````@```'@)``!X"0``#@4``````````````0````````!.````____
M;P(```"&#@``A@X``-P````%``````````(````"````6P```/[__V\"````
M9`\``&0/``!@````!@````,````$`````````&H````)`````@```,0/``#$
M#P``\`````4`````````!`````@```!S````"0```$(```"T$```M!`````"
M```%````%0````0````(````?`````$````&````M!(``+02```0````````
M```````$`````````'<````!````!@```,02``#$$@``%`,`````````````
M!`````0```""`````0````8```#8%0``V!4``#AU``````````````@`````
M````B`````$````&````$(L``!"+```,```````````````$`````````(X`
M```!`````@```!R+```<BP``H#\`````````````!`````````"6`````0``
M<((```"\R@``O,H```@````-``````````0`````````H0````$````"````
MQ,H``,3*```$```````````````$`````````*L````.`````P```(#-`0"`
MS0``!```````````````!`````0```"W````#P````,```"$S0$`A,T```0`
M``````````````0````$````PP````8````#````B,T!`(C-```H`0``!@``
M```````$````"````,P````!`````P```+#.`0"PS@``4`$`````````````
M!`````0```#1`````0````,`````T`$``-```$````````````````0`````
M````UP````@````#````0-`!`$#0```8$``````````````$`````````-P`
M```!````,`````````!`T```0@```````````````0````$```#E`````P``
M<```````````@M```"H```````````````$``````````0````,`````````
<`````*S0``#U```````````````!````````````
